@@ -31,13 +31,13 @@ my $oRenderTag =
 {
     'markdown' =>
     {
-        'br' => ['\n', ''],
         'quote' => ['"', '"'],
         'b' => ['**', '**'],
         'i' => ['_', '_'],
         # 'bi' => ['_**', '**_'],
-        'list-item' => ["\n", ""],
-        'list-item' => ['- ', "\n"],
+        'ul' => ["\n", ""],
+        'ol' => ["\n", "\n"],
+        'li' => ['- ', "\n"],
         'id' => ['`', '`'],
         'file' => ['`', '`'],
         'path' => ['`', '`'],
@@ -56,14 +56,13 @@ my $oRenderTag =
 
     'text' =>
     {
-        'br' => ['\n', ''],
         'quote' => ['"', '"'],
-        'p' => ['', "\n\n"],
         'b' => ['', ''],
         'i' => ['', ''],
         # 'bi' => ['', ''],
-        'list' => ["", "\n"],
-        'list-item' => ['* ', "\n"],
+        'ul' => ["\n", "\n"],
+        'ol' => ["\n", "\n"],
+        'li' => ['* ', "\n"],
         'id' => ['', ''],
         'host' => ['', ''],
         'file' => ['', ''],
@@ -79,19 +78,18 @@ my $oRenderTag =
         'backrest' => [undef, ''],
         'proper' => ['', ''],
         'postgres' => ['PostgreSQL', ''],
-        'admonition' => ['', "\n\n"],
+        'admonition' => ["\n", "\n\n"],
     },
 
     'latex' =>
     {
-        'br' => ['\\\vspace{1em}', ''],
         'quote' => ['``', '"'],
-        'p' => ["\n\\begin{sloppypar}", "\\end{sloppypar}\n"],
         'b' => ['\textbf{', '}'],
         'i' => ['\textit{', '}'],
         # 'bi' => ['', ''],
-        'list' => ["\\begin{itemize}\n", "\\end{itemize}\n"],
-        'list-item' => ['\item ', "\n"],
+        'ul' => ["\\begin{itemize}\n", "\\end{itemize}\n"],
+        # 'ol' => ["\n", "\n"],
+        'li' => ['\item ', "\n"],
         'id' => ['\textnormal{\texttt{', '}}'],
         'host' => ['\textnormal{\textbf{', '}}'],
         'file' => ['\textnormal{\texttt{', '}}'],
@@ -112,20 +110,18 @@ my $oRenderTag =
         'backrest' => [undef, ''],
         'proper' => ['\textnormal{\texttt{', '}}'],
         'postgres' => ['PostgreSQL', ''],
-        'admonition' =>
-            ["\n\\vspace{.5em}\\begin{leftbar}\n\\begin{sloppypar}\\textit{\\textbf{", "}\\end{sloppypar}\n\\end{leftbar}\n"],
+        'admonition' => ["\n\\begin{leftbar}\n\\textit{\\textbf{", "}\n\\end{leftbar}\n"],
     },
 
     'html' =>
     {
-        'br' => ['<br/>', ''],
         'quote' => ['<q>', '</q>'],
         'b' => ['<b>', '</b>'],
         'i' => ['<i>', '</i>'],
-        'p' => ['', ''],
         # 'bi' => ['<i><b>', '</b></i>'],
-        'list' => ['<ul class="list-unordered">', '</ul>'],
-        'list-item' => ['<li class="list-unordered">', '</li>'],
+        'ul' => ['<ul>', '</ul>'],
+        'ol' => ['<ol>', '</ol>'],
+        'li' => ['<li>', '</li>'],
         'id' => ['<span class="id">', '</span>'],
         'host' => ['<span class="host">', '</span>'],
         'file' => ['<span class="file">', '</span>'],
@@ -197,14 +193,29 @@ sub new
         my $oRenderOut =
             $self->{oManifest}->renderOutGet($self->{strType} eq 'latex' ? 'pdf' : $self->{strType}, $self->{strRenderOutKey});
 
-        # If these are the backrest docs then load the help
+        # If these are the backrest docs then load the reference
         if ($self->{oManifest}->isBackRest())
         {
             $self->{oReference} =
-                new pgBackRestDoc::Common::DocConfig(${$self->{oManifest}->sourceGet('help')}{doc}, $self);
+                new pgBackRestDoc::Common::DocConfig(${$self->{oManifest}->sourceGet('reference')}{doc}, $self);
         }
 
-        if (defined($$oRenderOut{source}) && $$oRenderOut{source} eq 'release' && $self->{oManifest}->isBackRest())
+        if (defined($$oRenderOut{source}) && $$oRenderOut{source} eq 'reference' && $self->{oManifest}->isBackRest())
+        {
+            if ($self->{strRenderOutKey} eq 'configuration')
+            {
+                $self->{oDoc} = $self->{oReference}->helpConfigDocGet();
+            }
+            elsif ($self->{strRenderOutKey} eq 'command')
+            {
+                $self->{oDoc} = $self->{oReference}->helpCommandDocGet();
+            }
+            else
+            {
+                confess &log(ERROR, "cannot render $self->{strRenderOutKey} from source $$oRenderOut{source}");
+            }
+        }
+        elsif (defined($$oRenderOut{source}) && $$oRenderOut{source} eq 'release' && $self->{oManifest}->isBackRest())
         {
             require pgBackRestDoc::Custom::DocCustomRelease;
             pgBackRestDoc::Custom::DocCustomRelease->import();
@@ -460,7 +471,7 @@ sub build
             $oNode->paramSet('depend-default', $strDependPrev);
         }
 
-        # Set log to true if this section has an execute list. This helps reduce the info logging by only showing sections that are
+        # Set log to true if this section has an execute list.  This helps reduce the info logging by only showing sections that are
         # likely to take a log time.
         $oNode->paramSet('log', $self->{bExe} && $oNode->nodeList('execute-list', false) > 0 ? true : false);
 
@@ -718,14 +729,6 @@ sub processTag
         if (!defined($strUrl))
         {
             my $strPage = $self->variableReplace($oTag->paramGet('page', false));
-            my $strSection = $oTag->paramGet('section', false);
-
-            # If a page/section link points to the current page then remove the page portion
-            if (defined($strPage) && defined($strSection) && defined($self->{strRenderOutKey}) &&
-                $strPage eq $self->{strRenderOutKey})
-            {
-                undef($strPage);
-            }
 
             # If this is a page URL
             if (defined($strPage))
@@ -738,20 +741,11 @@ sub processTag
                 # Else point locally
                 else
                 {
-                    if ($strType eq 'html')
+                    if ($strType eq 'html' || $strType eq 'markdown')
                     {
-                        $strUrl = "${strPage}.html". (defined($strSection) ? '#' . substr($strSection, 1) : '');
-                    }
-                    elsif ($strType eq 'markdown')
-                    {
-                        if (defined($strSection))
-                        {
-                            confess &log(
-                                ERROR,
-                                "page and section links not supported for type ${strType}, value '" . $oTag->valueGet() . "'");
-                        }
-
-                        $strUrl = "${strPage}.md";
+                        $strUrl =
+                            $oTag->paramGet('page', false) . '.' .
+                            ($strType eq 'html' ? $strType : '.md');
                     }
                     else
                     {
@@ -811,10 +805,6 @@ sub processTag
                 $strBuffer = "\\hyperref[$strUrl]{" . $oTag->valueGet() . "}";
             }
         }
-        elsif ($strType eq 'text')
-        {
-            $strBuffer = $oTag->valueGet();
-        }
         else
         {
             confess "'link' tag not valid for type ${strType}";
@@ -832,14 +822,14 @@ sub processTag
 
         $strBuffer .= $strStart;
 
-        # Admonitions in the help materials are tags of the text element rather than field elements of the document so special
+        # Admonitions in the reference materials are tags of the text element rather than field elements of the document so special
         # handling is required
         if ($strTag eq 'admonition')
         {
             $strBuffer .= $self->processAdmonitionStart($oTag);
         }
 
-        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'list-item' || $strTag eq 'code-block' || $strTag eq 'summary'
+        if ($strTag eq 'p' || $strTag eq 'title' || $strTag eq 'li' || $strTag eq 'code-block' || $strTag eq 'summary'
             || $strTag eq 'admonition')
         {
             $strBuffer .= $self->processText($oTag);
@@ -975,7 +965,6 @@ sub processText
 
     my $strType = $self->{strType};
     my $strBuffer = '';
-    my $strLastTag = 'body';
 
     foreach my $oNode ($oText->nodeList(undef, false))
     {
@@ -986,30 +975,11 @@ sub processText
                 confess &log(ERROR, "unable to process quotes in string (use <quote> instead):\n${oNode}");
             }
 
-            # Skip text nodes with linefeeds since they happen between tags
-            if (index($oNode, "\n") == -1)
-            {
-                $strBuffer .= $oNode;
-            }
+            $strBuffer .= $oNode;
         }
         else
         {
-            # Add br tags to separate paragraphs and linefeeds to make the output more diffable. This is needed because of the hacky
-            # way config text is being rendered in the final document, i.e. by passing rendered HTML into divs rather than XML to be
-            # rendered at that time.
-            if ($strLastTag eq 'p' && $strType eq 'html')
-            {
-                $strBuffer .= "<br/>\n";
-
-                if ($oNode->nameGet() eq 'p')
-                {
-                    $strBuffer .= "<br/>\n";
-                }
-            }
-
             $strBuffer .= $self->processTag($oNode);
-
-            $strLastTag = $oNode->nameGet();
         }
     }
     #
@@ -1064,11 +1034,6 @@ sub processText
         }
     }
 
-    if ($strType eq 'html')
-    {
-        $strBuffer =~ s/ma[s]ter/ma&#115;ter/g;
-    }
-
     if ($strType eq 'text')
     {
         $strBuffer =~ s/\&mdash\;/--/g;
