@@ -4,6 +4,7 @@ Archive Push File
 #ifndef COMMAND_ARCHIVE_PUSH_FILE_H
 #define COMMAND_ARCHIVE_PUSH_FILE_H
 
+#include "common/compress/helper.h"
 #include "common/crypto/common.h"
 #include "common/type/string.h"
 #include "storage/storage.h"
@@ -13,6 +14,6 @@ Functions
 ***********************************************************************************************************************************/
 String *archivePushFile(
     const String *walSource, const String *archiveId, unsigned int pgVersion, uint64_t pgSystemId, const String *archiveFile,
-    CipherType cipherType, const String *cipherPass, bool compress, int compressLevel);
+    CipherType cipherType, const String *cipherPass, CompressType compressType, int compressLevel);
 
 #endif
