@@ -11,8 +11,8 @@ Archive Push Command
 #include "command/archive/push/protocol.h"
 #include "command/command.h"
 #include "command/control/common.h"
+#include "common/compress/helper.h"
 #include "common/debug.h"
-#include "common/fork.h"
 #include "common/log.h"
 #include "common/memContext.h"
 #include "common/wait.h"
@@ -107,7 +107,7 @@ archivePushReadyList(const String *walPath)
                 strSubN(strLstGet(readyListRaw, readyIdx), 0, strSize(strLstGet(readyListRaw, readyIdx)) - STATUS_EXT_READY_SIZE));
         }
 
-        strLstMove(result, MEM_CONTEXT_OLD());
+        strLstMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -173,7 +173,7 @@ archivePushProcessList(const String *walPath)
         }
 
         // Return all ready files that are not in the ok list
-        result = strLstMove(strLstMergeAnti(readyList, okList), MEM_CONTEXT_OLD());
+        result = strLstMove(strLstMergeAnti(readyList, okList), memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -233,13 +233,15 @@ archivePushCheck(CipherType cipherType, const String *cipherPass)
                 archiveInfo.systemId);
         }
 
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result.pgVersion = controlInfo.version;
-        result.pgSystemId = controlInfo.systemId;
-        result.pgWalSegmentSize = controlInfo.walSegmentSize;
-        result.archiveId = strDup(archiveId);
-        result.archiveCipherPass = strDup(infoArchiveCipherPass(info));
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result.pgVersion = controlInfo.version;
+            result.pgSystemId = controlInfo.systemId;
+            result.pgWalSegmentSize = controlInfo.walSegmentSize;
+            result.archiveId = strDup(archiveId);
+            result.archiveCipherPass = strDup(infoArchiveCipherPass(info));
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -256,6 +258,9 @@ cmdArchivePush(void)
 
     ASSERT(cfgCommand() == cfgCmdArchivePush);
 
+    // PostgreSQL must be local
+    pgIsLocalVerify();
+
     MEM_CONTEXT_TEMP_BEGIN()
     {
         // Make sure there is a parameter to retrieve the WAL segment from
@@ -275,16 +280,16 @@ cmdArchivePush(void)
         {
             bool pushed = false;                                        // Has the WAL segment been pushed yet?
             bool forked = false;                                        // Has the async process been forked yet?
-            bool confessOnError = false;                                // Should we confess errors?
+            bool throwOnError = false;                                  // Should we throw errors?
 
             // Loop and wait for the WAL segment to be pushed
             Wait *wait = waitNew((TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
 
             do
             {
-                // Check if the WAL segment has been pushed.  Errors will not be confessed on the first try to allow the async
-                // process a chance to fix them.
-                pushed = archiveAsyncStatus(archiveModePush, archiveFile, confessOnError);
+                // Check if the WAL segment has been pushed.  Errors will not be thrown on the first try to allow the async process
+                // a chance to fix them.
+                pushed = archiveAsyncStatus(archiveModePush, archiveFile, throwOnError);
 
                 // If the WAL segment has not already been pushed then start the async process to push it.  There's no point in
                 // forking the async process off more than once so track that as well.  Use an archive lock to prevent more than
@@ -299,35 +304,26 @@ cmdArchivePush(void)
                     kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("off"));
 
                     // Generate command options
-                    StringList *commandExec = cfgExecParam(cfgCmdArchivePushAsync, optionReplace, true);
+                    StringList *commandExec = cfgExecParam(cfgCmdArchivePush, cfgCmdRoleAsync, optionReplace, true, false);
                     strLstInsert(commandExec, 0, cfgExe());
                     strLstAdd(commandExec, strPath(walFile));
 
+                    // Clear errors for the current archive file
+                    archiveAsyncErrorClear(archiveModePush, archiveFile);
+
                     // Release the lock so the child process can acquire it
                     lockRelease(true);
 
-                    // Fork off the async process
-                    if (forkSafe() == 0)
-                    {
-                        // Disable logging and close log file
-                        logClose();
-
-                        // Detach from parent process
-                        forkDetach();
-
-                        // Execute the binary.  This statement will not return if it is successful.
-                        THROW_ON_SYS_ERROR(
-                            execvp(strPtr(cfgExe()), (char ** const)strLstPtr(commandExec)) == -1,
-                            ExecuteError, "unable to execute '" CFGCMD_ARCHIVE_PUSH_ASYNC "'");
-                    }
+                    // Execute the async process
+                    archiveAsyncExec(archiveModePush, commandExec);
 
                     // Mark the async process as forked so it doesn't get forked again.  A single run of the async process should be
                     // enough to do the job, running it again won't help anything.
                     forked = true;
                 }
 
-                // Now that the async process has been launched, confess any errors that are found
-                confessOnError = true;
+                // Now that the async process has been launched, throw any errors that are found
+                throwOnError = true;
             }
             while (!pushed && waitMore(wait));
 
@@ -364,7 +360,7 @@ cmdArchivePush(void)
                 String *warning = archivePushFile(
                     walFile, archiveInfo.archiveId, archiveInfo.pgVersion, archiveInfo.pgSystemId, archiveFile,
                     cipherType(cfgOptionStr(cfgOptRepoCipherType)), archiveInfo.archiveCipherPass,
-                    cfgOptionBool(cfgOptCompress), cfgOptionInt(cfgOptCompressLevel));
+                    compressTypeEnum(cfgOptionStr(cfgOptCompressType)), cfgOptionInt(cfgOptCompressLevel));
 
                 // If a warning was returned then log it
                 if (warning != NULL)
@@ -389,7 +385,7 @@ typedef struct ArchivePushAsyncData
     const StringList *walFileList;                                  // List of wal files to process
     unsigned int walFileIdx;                                        // Current index in the list to be processed
     CipherType cipherType;                                          // Cipher type
-    bool compress;                                                  // Compress wal files
+    CompressType compressType;                                      // Type of compression for WAL segments
     int compressLevel;                                              // Compression level for wal files
     ArchivePushCheckResult archiveInfo;                             // Archive info
 } ArchivePushAsyncData;
@@ -420,7 +416,7 @@ static ProtocolParallelJob *archivePushAsyncCallback(void *data, unsigned int cl
         protocolCommandParamAdd(command, VARSTR(walFile));
         protocolCommandParamAdd(command, VARUINT(jobData->cipherType));
         protocolCommandParamAdd(command, VARSTR(jobData->archiveInfo.archiveCipherPass));
-        protocolCommandParamAdd(command, VARBOOL(jobData->compress));
+        protocolCommandParamAdd(command, VARUINT(jobData->compressType));
         protocolCommandParamAdd(command, VARINT(jobData->compressLevel));
 
         FUNCTION_TEST_RETURN(protocolParallelJobNew(VARSTR(walFile), command));
@@ -434,7 +430,10 @@ cmdArchivePushAsync(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
 
-    ASSERT(cfgCommand() == cfgCmdArchivePushAsync);
+    ASSERT(cfgCommand() == cfgCmdArchivePush && cfgCommandRole() == cfgCmdRoleAsync);
+
+    // PostgreSQL must be local
+    pgIsLocalVerify();
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
@@ -447,7 +446,7 @@ cmdArchivePushAsync(void)
         ArchivePushAsyncData jobData =
         {
             .walPath = strLstGet(commandParam, 0),
-            .compress = cfgOptionBool(cfgOptCompress),
+            .compressType = compressTypeEnum(cfgOptionStr(cfgOptCompressType)),
             .compressLevel = cfgOptionInt(cfgOptCompressLevel),
         };
 
@@ -459,7 +458,7 @@ cmdArchivePushAsync(void)
             // Get a list of WAL files that are ready for processing
             jobData.walFileList = archivePushProcessList(jobData.walPath);
 
-            // The archive-push-async command should not have been called unless there are WAL files to process
+            // The archive-push:async command should not have been called unless there are WAL files to process
             if (strLstSize(jobData.walFileList) == 0)
                 THROW(AssertError, "no WAL files to process");
 
