@@ -16,6 +16,11 @@ TLS Client
 #include <netinet/in.h>
 #endif
 
+#ifdef __linux__
+#include <netinet/in.h>
+#include <netinet/tcp.h>
+#endif
+
 #include <openssl/conf.h>
 #include <openssl/ssl.h>
 #include <openssl/x509v3.h>
@@ -143,15 +148,18 @@ tlsClientNew(
     MEM_CONTEXT_NEW_BEGIN("TlsClient")
     {
         this = memNew(sizeof(TlsClient));
-        this->memContext = MEM_CONTEXT_NEW();
 
-        this->host = strDup(host);
-        this->port = port;
-        this->timeout = timeout;
-        this->verifyPeer = verifyPeer;
+        *this = (TlsClient)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .host = strDup(host),
+            .port = port,
+            .timeout = timeout,
+            .verifyPeer = verifyPeer,
 
-        // Initialize socket to -1 so we know when it is disconnected
-        this->socket = -1;
+            // Initialize socket to -1 so we know when it is disconnected
+            .socket = -1,
+        };
 
         // Setup TLS context
         // -------------------------------------------------------------------------------------------------------------------------
@@ -573,12 +581,12 @@ tlsClientOpen(TlsClient *this)
                 TRY_BEGIN()
                 {
                     // Set hits that narrow the type of address we are looking for -- we'll take ipv4 or ipv6
-                    struct addrinfo hints;
-
-                    memset(&hints, 0, sizeof(hints));
-                    hints.ai_family = AF_UNSPEC;
-                    hints.ai_socktype = SOCK_STREAM;
-                    hints.ai_protocol = IPPROTO_TCP;
+                    struct addrinfo hints = (struct addrinfo)
+                    {
+                        .ai_family = AF_UNSPEC,
+                        .ai_socktype = SOCK_STREAM,
+                        .ai_protocol = IPPROTO_TCP,
+                    };
 
                     // Convert the port to a zero-terminated string for use with getaddrinfo()
                     char port[CVT_BASE10_BUFFER_SIZE];
@@ -614,7 +622,7 @@ tlsClientOpen(TlsClient *this)
                     int socketValue = 1;
 
                     THROW_ON_SYS_ERROR(
-                        setsockopt(this->socket, SOL_SOCKET, SO_KEEPALIVE, &socketValue, sizeof(int)) == -1, ProtocolError,
+                        setsockopt(this->socket, IPPROTO_TCP, SO_KEEPALIVE, &socketValue, sizeof(int)) == -1, ProtocolError,
                          "unable set SO_KEEPALIVE");
 
                     // Set per-connection keepalive options if they are available
@@ -622,18 +630,19 @@ tlsClientOpen(TlsClient *this)
                     socketValue = 3;
 
                     THROW_ON_SYS_ERROR(
-                        setsockopt(this->socket, SOL_SOCKET, TCP_KEEPIDLE, &socketValue, sizeof(int)) == -1, ProtocolError,
+                        setsockopt(this->socket, IPPROTO_TCP, TCP_KEEPCNT, &socketValue, sizeof(int)) == -1, ProtocolError,
+                         "unable set SO_KEEPCNT");
+
+                    // First try + n failures to get to the timeout
+                    socketValue = (int)this->timeout / (socketValue + 1);
+
+                    THROW_ON_SYS_ERROR(
+                        setsockopt(this->socket, IPPROTO_TCP, TCP_KEEPIDLE, &socketValue, sizeof(int)) == -1, ProtocolError,
                          "unable set SO_KEEPIDLE");
 
                     THROW_ON_SYS_ERROR(
-                        setsockopt(this->socket, SOL_SOCKET, TCP_KEEPINTVL, &socketValue, sizeof(int)) == -1, ProtocolError,
+                        setsockopt(this->socket, IPPROTO_TCP, TCP_KEEPINTVL, &socketValue, sizeof(int)) == -1, ProtocolError,
                          "unable set SO_KEEPINTVL");
-
-                    socketValue = this->timeout / socketValue;
-
-                    THROW_ON_SYS_ERROR(
-                        setsockopt(this->socket, SOL_SOCKET, TCP_KEEPCNT, &socketValue, sizeof(int)) == -1, ProtocolError,
-                         "unable set SO_KEEPCNT");
 #endif
 
                     // Negotiate TLS
