@@ -118,14 +118,14 @@ jsonToNumberInternal(const char *json, unsigned int *jsonPos)
         String *resultStr = strNewN(json + beginPos, *jsonPos - beginPos);
 
         // Convert the string to a integer variant
-        memContextSwitch(MEM_CONTEXT_OLD());
-
-        if (intSigned)
-            result = varNewInt64(cvtZToInt64(strPtr(resultStr)));
-        else
-            result = varNewUInt64(cvtZToUInt64(strPtr(resultStr)));
-
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            if (intSigned)
+                result = varNewInt64(cvtZToInt64(strPtr(resultStr)));
+            else
+                result = varNewUInt64(cvtZToUInt64(strPtr(resultStr)));
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -242,12 +242,24 @@ jsonToStrInternal(const char *json, unsigned int *jsonPos)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
+        // Skip the beginning "
         (*jsonPos)++;
 
+        // Track portion of string with no escapes
+        const char *noEscape = NULL;
+        size_t noEscapeSize = 0;
+
         while (json[*jsonPos] != '"')
         {
             if (json[*jsonPos] == '\\')
             {
+                // Copy portion of string without escapes
+                if (noEscapeSize > 0)
+                {
+                    strCatZN(result, noEscape, noEscapeSize);
+                    noEscapeSize = 0;
+                }
+
                 (*jsonPos)++;;
 
                 switch (json[*jsonPos])
@@ -293,12 +305,20 @@ jsonToStrInternal(const char *json, unsigned int *jsonPos)
                 if (json[*jsonPos] == '\0')
                     THROW(JsonFormatError, "expected '\"' but found null delimiter");
 
-                    strCatChr(result, json[*jsonPos]);
+                // If escape string is zero size then start it
+                if (noEscapeSize == 0)
+                    noEscape = json + *jsonPos;
+
+                noEscapeSize++;
             }
 
             (*jsonPos)++;;
         };
 
+        // Copy portion of string without escapes
+        if (noEscapeSize > 0)
+            strCatZN(result, noEscape, noEscapeSize);
+
         // Advance the character array pointer to the next element after the string
         (*jsonPos)++;;
     }
@@ -442,9 +462,11 @@ jsonToVarLstInternal(const char *json, unsigned int *jsonPos)
                     jsonConsumeWhiteSpace(json, jsonPos);
                 }
 
-                memContextSwitch(MEM_CONTEXT_OLD());
-                varLstAdd(result, jsonToVarInternal(json, jsonPos));
-                memContextSwitch(MEM_CONTEXT_TEMP());
+                MEM_CONTEXT_PRIOR_BEGIN()
+                {
+                    varLstAdd(result, jsonToVarInternal(json, jsonPos));
+                }
+                MEM_CONTEXT_PRIOR_END();
 
                 jsonConsumeWhiteSpace(json, jsonPos);
             }
@@ -668,6 +690,10 @@ jsonFromStrInternal(String *json, const String *string)
     {
         strCatChr(json, '"');
 
+        // Track portion of string with no escapes
+        const char *noEscape = NULL;
+        size_t noEscapeSize = 0;
+
         for (unsigned int stringIdx = 0; stringIdx < strSize(string); stringIdx++)
         {
             char stringChr = strPtr(string)[stringIdx];
@@ -675,39 +701,84 @@ jsonFromStrInternal(String *json, const String *string)
             switch (stringChr)
             {
                 case '"':
-                    strCat(json, "\\\"");
-                    break;
-
                 case '\\':
-                    strCat(json, "\\\\");
-                    break;
-
                 case '\n':
-                    strCat(json, "\\n");
-                    break;
-
                 case '\r':
-                    strCat(json, "\\r");
-                    break;
-
                 case '\t':
-                    strCat(json, "\\t");
-                    break;
-
                 case '\b':
-                    strCat(json, "\\b");
-                    break;
-
                 case '\f':
-                    strCat(json, "\\f");
+                {
+                    // Copy portion of string without escapes
+                    if (noEscapeSize > 0)
+                    {
+                        strCatZN(json, noEscape, noEscapeSize);
+                        noEscapeSize = 0;
+                    }
+
+                    switch (stringChr)
+                    {
+                        case '"':
+                        {
+                            strCat(json, "\\\"");
+                            break;
+                        }
+
+                        case '\\':
+                        {
+                            strCat(json, "\\\\");
+                            break;
+                        }
+
+                        case '\n':
+                        {
+                            strCat(json, "\\n");
+                            break;
+                        }
+
+                        case '\r':
+                        {
+                            strCat(json, "\\r");
+                            break;
+                        }
+
+                        case '\t':
+                        {
+                            strCat(json, "\\t");
+                            break;
+                        }
+
+                        case '\b':
+                        {
+                            strCat(json, "\\b");
+                            break;
+                        }
+
+                        case '\f':
+                        {
+                            strCat(json, "\\f");
+                            break;
+                        }
+                    }
+
                     break;
+                }
 
                 default:
-                    strCatChr(json, stringChr);
+                {
+                    // If escape string is zero size then start it
+                    if (noEscapeSize == 0)
+                        noEscape = strPtr(string) + stringIdx;
+
+                    noEscapeSize++;
                     break;
+                }
             }
         }
 
+        // Copy portion of string without escapes
+        if (noEscapeSize > 0)
+            strCatZN(json, noEscape, noEscapeSize);
+
         strCatChr(json, '"');
     }
 
@@ -863,10 +934,12 @@ jsonFromKv(const KeyValue *kv)
     {
         String *jsonStr = jsonFromKvInternal(kv);
 
-        // Duplicate the string into the calling context
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result = strDup(jsonStr);
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        // Duplicate the string into the prior context
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result = strDup(jsonStr);
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -981,10 +1054,12 @@ jsonFromVar(const Variant *var)
         else
             THROW(JsonFormatError, "variant type is invalid");
 
-        // Duplicate the string into the calling context
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result = strDup(jsonStr);
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        // Duplicate the string into the prior context
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result = strDup(jsonStr);
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
