@@ -21,7 +21,9 @@ Constant strings that are generally useful
 ***********************************************************************************************************************************/
 STRING_EXTERN(BRACKETL_STR,                                         "[");
 STRING_EXTERN(BRACKETR_STR,                                         "]");
+STRING_EXTERN(COLON_STR,                                            COLON_Z);
 STRING_EXTERN(CR_STR,                                               "\r");
+STRING_EXTERN(DASH_STR,                                             DASH_Z);
 STRING_EXTERN(DOT_STR,                                              ".");
 STRING_EXTERN(DOTDOT_STR,                                           "..");
 STRING_EXTERN(EMPTY_STR,                                            "");
@@ -75,11 +77,18 @@ strNew(const char *string)
 
     // Create object
     String *this = memNew(sizeof(String));
-    this->memContext = memContextCurrent();
-    this->size = (unsigned int)stringSize;
+
+    *this = (String)
+    {
+        .memContext = memContextCurrent(),
+        .size = (unsigned int)stringSize,
+
+        // A zero-length string is not very useful so assume this string is being created for appending and allocate extra space
+        .extra = stringSize == 0 ? STRING_EXTRA_MIN : 0,
+    };
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
+    this->buffer = memNew(this->size + this->extra + 1);
     strcpy(this->buffer, string);
 
     FUNCTION_TEST_RETURN(this);
@@ -105,11 +114,15 @@ strNewBuf(const Buffer *buffer)
 
     // Create object
     String *this = memNew(sizeof(String));
-    this->memContext = memContextCurrent();
-    this->size = (unsigned int)bufUsed(buffer);
+
+    *this = (String)
+    {
+        .memContext = memContextCurrent(),
+        .size = (unsigned int)bufUsed(buffer),
+    };
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
+    this->buffer = memNew(this->size + 1);
     memcpy(this->buffer, (char *)bufPtr(buffer), this->size);
     this->buffer[this->size] = 0;
 
@@ -130,7 +143,11 @@ strNewFmt(const char *format, ...)
 
     // Create object
     String *this = memNew(sizeof(String));
-    this->memContext = memContextCurrent();
+
+    *this = (String)
+    {
+        .memContext = memContextCurrent(),
+    };
 
     // Determine how long the allocated string needs to be
     va_list argumentList;
@@ -143,7 +160,7 @@ strNewFmt(const char *format, ...)
 
     // Allocate and assign string
     this->size = (unsigned int)formatSize;
-    this->buffer = memNewRaw(this->size + 1);
+    this->buffer = memNew(this->size + 1);
     va_start(argumentList, format);
     vsnprintf(this->buffer, this->size + 1, format, argumentList);
     va_end(argumentList);
@@ -171,11 +188,15 @@ strNewN(const char *string, size_t size)
 
     // Create object
     String *this = memNew(sizeof(String));
-    this->memContext = memContextCurrent();
-    this->size = (unsigned int)size;
+
+    *this = (String)
+    {
+        .memContext = memContextCurrent(),
+        .size = (unsigned int)size,
+    };
 
     // Allocate and assign string
-    this->buffer = memNewRaw(this->size + 1);
+    this->buffer = memNew(this->size + 1);
     strncpy(this->buffer, string, this->size);
     this->buffer[this->size] = 0;
 
@@ -259,9 +280,13 @@ strResize(String *this, size_t requested)
         // Calculate new extra needs to satisfy request and leave extra space for new growth
         this->extra = (unsigned int)requested + ((this->size + (unsigned int)requested) / 2);
 
+        // Adding too little extra space usually leads to immediate resizing so enforce a minimum
+        if (this->extra < STRING_EXTRA_MIN)
+            this->extra = STRING_EXTRA_MIN;
+
         MEM_CONTEXT_BEGIN(this->memContext)
         {
-            this->buffer = memGrowRaw(this->buffer, this->size + this->extra + 1);
+            this->buffer = memResize(this->buffer, this->size + this->extra + 1);
         }
         MEM_CONTEXT_END();
     }
@@ -297,6 +322,32 @@ strCat(String *this, const char *cat)
     FUNCTION_TEST_RETURN(this);
 }
 
+String *
+strCatZN(String *this, const char *cat, size_t size)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, this);
+        FUNCTION_TEST_PARAM(STRINGZ, cat);
+        FUNCTION_TEST_PARAM(SIZE, size);
+    FUNCTION_TEST_END();
+
+    ASSERT(this != NULL);
+    ASSERT(cat != NULL);
+
+    // Ensure there is enough space to grow the string
+    strResize(this, size);
+
+    // Append the string
+    strncpy(this->buffer + this->size, cat, size);
+    this->buffer[this->size + size] = '\0';
+
+    // Update size/extra
+    this->size += (unsigned int)size;
+    this->extra -= (unsigned int)size;
+
+    FUNCTION_TEST_RETURN(this);
+}
+
 /***********************************************************************************************************************************
 Append a character
 ***********************************************************************************************************************************/
@@ -667,14 +718,14 @@ strPathAbsolute(const String *this, const String *base)
                 strLstRemoveIdx(pathList, 0);
             }
 
-            memContextSwitch(MEM_CONTEXT_OLD());
-
-            if (strLstSize(baseList) == 1)
-                result = strDup(FSLASH_STR);
-            else
-                result = strLstJoin(baseList, "/");
-
-            memContextSwitch(MEM_CONTEXT_TEMP());
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                if (strLstSize(baseList) == 1)
+                    result = strDup(FSLASH_STR);
+                else
+                    result = strLstJoin(baseList, "/");
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
         MEM_CONTEXT_TEMP_END();
     }
@@ -696,12 +747,7 @@ strPtr(const String *this)
         FUNCTION_TEST_PARAM(STRING, this);
     FUNCTION_TEST_END();
 
-    char *result = NULL;
-
-    if (this != NULL)
-        result = this->buffer;
-
-    FUNCTION_TEST_RETURN(result);
+    FUNCTION_TEST_RETURN(this == NULL ? NULL : this->buffer);
 }
 
 /***********************************************************************************************************************************
@@ -852,7 +898,7 @@ strTrim(String *this)
             MEM_CONTEXT_BEGIN(this->memContext)
             {
                 // Resize the buffer
-                this->buffer = memGrowRaw(this->buffer, this->size + 1);
+                this->buffer = memResize(this->buffer, this->size + 1);
             }
             MEM_CONTEXT_END();
         }
@@ -910,7 +956,7 @@ strTrunc(String *this, int idx)
         MEM_CONTEXT_BEGIN(this->memContext)
         {
             // Resize the buffer
-            this->buffer = memGrowRaw(this->buffer, this->size + 1);
+            this->buffer = memResize(this->buffer, this->size + 1);
         }
         MEM_CONTEXT_END();
     }
