@@ -445,8 +445,7 @@ configParse(unsigned int argListSize, const char *argList[], bool resetLogLevel)
         opterr = false;
 
         // List of parsed options
-        ParseOption parseOptionList[CFG_OPTION_TOTAL];
-        memset(&parseOptionList, 0, sizeof(parseOptionList));
+        ParseOption parseOptionList[CFG_OPTION_TOTAL] = {{.found = false}};
 
         // Only the first non-option parameter should be treated as a command so track if the command has been set
         bool commandSet = false;
@@ -461,18 +460,34 @@ configParse(unsigned int argListSize, const char *argList[], bool resetLogLevel)
                     // The first argument should be the command
                     if (!commandSet)
                     {
+                        const char *command = argList[optind - 1];
+
                         // Try getting the command from the valid command list
-                        TRY_BEGIN()
+                        ConfigCommand commandId = cfgCommandId(command, false);
+                        ConfigCommandRole commandRoleId = cfgCmdRoleDefault;
+
+                        // If not successful then a command role may be appended
+                        if (commandId == cfgCmdNone)
                         {
-                            cfgCommandSet(cfgCommandId(argList[optind - 1]));
+                            const StringList *commandPart = strLstNewSplit(STR(command), COLON_STR);
+
+                            if (strLstSize(commandPart) == 2)
+                            {
+                                // Get command id
+                                commandId = cfgCommandId(strPtr(strLstGet(commandPart, 0)), false);
+
+                                // If command id is valid then get command role id
+                                if (commandId != cfgCmdNone)
+                                    commandRoleId = cfgCommandRoleEnum(strLstGet(commandPart, 1));
+                            }
                         }
-                        // Assert error means the command does not exist, which is correct for all usages but this one (since we
-                        // don't have any control over what the user passes), so modify the error code and message.
-                        CATCH(AssertError)
-                        {
-                            THROW_FMT(CommandInvalidError, "invalid command '%s'", argList[optind - 1]);
-                        }
-                        TRY_END();
+
+                        // Error when command does not exist
+                        if (commandId == cfgCmdNone)
+                            THROW_FMT(CommandInvalidError, "invalid command '%s'", command);
+
+                        //  Set the command
+                        cfgCommandSet(commandId, commandRoleId);
 
                         if (cfgCommand() == cfgCmdHelp)
                             cfgCommandHelpSet(true);
@@ -599,8 +614,8 @@ configParse(unsigned int argListSize, const char *argList[], bool resetLogLevel)
         }
 
         // Enable logging (except for local and remote commands) so config file warnings will be output
-        if (cfgCommand() != cfgCmdLocal && cfgCommand() != cfgCmdRemote && resetLogLevel)
-            logInit(logLevelWarn, logLevelWarn, logLevelOff, false, 1);
+        if (cfgCommandRole() != cfgCmdRoleLocal && cfgCommandRole() != cfgCmdRoleRemote && resetLogLevel)
+            logInit(logLevelWarn, logLevelWarn, logLevelOff, false, 1, false);
 
         // Only continue if command options need to be validated, i.e. a real command is running or we are getting help for a
         // specific command and would like to display actual option values in the help.
