@@ -132,11 +132,21 @@ String *pgLsnToStr(uint64_t lsn);
 // Convert a timeline and lsn to a wal segment
 String *pgLsnToWalSegment(uint32_t timeline, uint64_t lsn, unsigned int walSegmentSize);
 
+// Convert a timeline and lsn range to a list of wal segments
+StringList *pgLsnRangeToWalSegmentList(
+    unsigned int pgVersion, uint32_t timeline, uint64_t lsnStart, uint64_t lsnStop, unsigned int walSegmentSize);
+
 // Get name used for lsn in functions (this was changed in PostgreSQL 10 for consistency since lots of names were changing)
 const String *pgLsnName(unsigned int pgVersion);
 
+// Calculate the checksum for a page. Page cannot be const because the page header is temporarily modified during processing.
+uint16_t pgPageChecksum(unsigned char *page, uint32_t blockNo);
+
 const String *pgWalName(unsigned int pgVersion);
 
+// Get wal path (this was changed in PostgreSQL 10 to avoid including "log" in the name)
+const String *pgWalPath(unsigned int pgVersion);
+
 // Get transaction commit log path (this was changed in PostgreSQL 10 to avoid including "log" in the name)
 const String *pgXactPath(unsigned int pgVersion);
 
