@@ -29,10 +29,16 @@ STRING_EXTERN(STORAGE_REPO_BACKUP_STR,                              STORAGE_REPO
 STRING_EXTERN(STORAGE_PATH_ARCHIVE_STR,                             STORAGE_PATH_ARCHIVE);
 STRING_EXTERN(STORAGE_PATH_BACKUP_STR,                              STORAGE_PATH_BACKUP);
 
+/***********************************************************************************************************************************
+Error message when writable storage is requested in dry-run mode
+***********************************************************************************************************************************/
+#define WRITABLE_WHILE_DRYRUN                                                                                                      \
+    "unable to get writable storage in dry-run mode or before dry-run is initialized"
+
 /***********************************************************************************************************************************
 Local variables
 ***********************************************************************************************************************************/
-static struct
+static struct StorageHelper
 {
     MemContext *memContext;                                         // Mem context for storage helper
 
@@ -47,6 +53,8 @@ static struct
 
     String *stanza;                                                 // Stanza for storage
     bool stanzaInit;                                                // Has the stanza been initialized?
+    bool dryRunInit;                                                // Has dryRun been initialized?  If not disallow writes.
+    bool dryRun;                                                    // Disallow writes in dry-run mode.
     RegExp *walRegExp;                                              // Regular expression for identifying wal files
 } storageHelper;
 
@@ -62,7 +70,11 @@ storageHelperInit(void)
     {
         MEM_CONTEXT_BEGIN(memContextTop())
         {
-            storageHelper.memContext = memContextNew("storageHelper");
+            MEM_CONTEXT_NEW_BEGIN("StorageHelper")
+            {
+                storageHelper.memContext = MEM_CONTEXT_NEW();
+            }
+            MEM_CONTEXT_NEW_END();
         }
         MEM_CONTEXT_END();
     }
@@ -70,6 +82,18 @@ storageHelperInit(void)
     FUNCTION_TEST_RETURN_VOID();
 }
 
+/**********************************************************************************************************************************/
+void
+storageHelperDryRunInit(bool dryRun)
+{
+    FUNCTION_TEST_VOID();
+
+    storageHelper.dryRunInit = true;
+    storageHelper.dryRun = dryRun;
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
 /***********************************************************************************************************************************
 Initialize the stanza and error if it changes
 ***********************************************************************************************************************************/
@@ -142,6 +166,7 @@ storageLocalWrite(void)
 
     FUNCTION_TEST_RETURN(storageHelper.storageLocalWrite);
 }
+
 /***********************************************************************************************************************************
 Get pg storage for the specified host id
 ***********************************************************************************************************************************/
@@ -173,7 +198,7 @@ storagePgGet(unsigned int hostId, bool write)
 }
 
 /***********************************************************************************************************************************
-Get ready-only PostgreSQL storage for a specific host id
+Get read-only PostgreSQL storage for a specific host id
 ***********************************************************************************************************************************/
 const Storage *
 storagePgId(unsigned int hostId)
@@ -189,7 +214,7 @@ storagePgId(unsigned int hostId)
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
             if (storageHelper.storagePg == NULL)
-                storageHelper.storagePg = memNew(sizeof(Storage *) * cfgDefOptionIndexTotal(cfgDefOptPgPath));
+                storageHelper.storagePg = memNewPtrArray(cfgDefOptionIndexTotal(cfgDefOptPgPath));
 
             storageHelper.storagePg[hostId - 1] = storagePgGet(hostId, false);
         }
@@ -200,7 +225,7 @@ storagePgId(unsigned int hostId)
 }
 
 /***********************************************************************************************************************************
-Get ready-only PostgreSQL storage for the host-id or the default of 1
+Get read-only PostgreSQL storage for the host-id or the default of 1
 ***********************************************************************************************************************************/
 const Storage *
 storagePg(void)
@@ -219,6 +244,10 @@ storagePgIdWrite(unsigned int hostId)
         FUNCTION_TEST_PARAM(UINT, hostId);
     FUNCTION_TEST_END();
 
+    // Writes not allowed in dry-run mode
+    if (!storageHelper.dryRunInit || storageHelper.dryRun)
+        THROW(AssertError, WRITABLE_WHILE_DRYRUN);
+
     if (storageHelper.storagePgWrite == NULL || storageHelper.storagePgWrite[hostId - 1] == NULL)
     {
         storageHelperInit();
@@ -226,7 +255,7 @@ storagePgIdWrite(unsigned int hostId)
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
             if (storageHelper.storagePgWrite == NULL)
-                storageHelper.storagePgWrite = memNew(sizeof(Storage *) * cfgDefOptionIndexTotal(cfgDefOptPgPath));
+                storageHelper.storagePgWrite = memNewPtrArray(cfgDefOptionIndexTotal(cfgDefOptPgPath));
 
             storageHelper.storagePgWrite[hostId - 1] = storagePgGet(hostId, true);
         }
@@ -369,6 +398,7 @@ storageRepoGet(const String *type, bool write)
 
         result = storageS3New(
             cfgOptionStr(cfgOptRepoPath), write, storageRepoPathExpression, cfgOptionStr(cfgOptRepoS3Bucket), endPoint,
+            strEqZ(cfgOptionStr(cfgOptRepoS3UriStyle), STORAGE_S3_URI_STYLE_HOST) ? storageS3UriStyleHost : storageS3UriStylePath,
             cfgOptionStr(cfgOptRepoS3Region), cfgOptionStr(cfgOptRepoS3Key), cfgOptionStr(cfgOptRepoS3KeySecret),
             cfgOptionTest(cfgOptRepoS3Token) ? cfgOptionStr(cfgOptRepoS3Token) : NULL, STORAGE_S3_PARTSIZE_MIN,
             STORAGE_S3_DELETE_MAX, host, port, STORAGE_S3_TIMEOUT_DEFAULT, cfgOptionBool(cfgOptRepoS3VerifyTls),
@@ -413,6 +443,10 @@ storageRepoWrite(void)
 {
     FUNCTION_TEST_VOID();
 
+    // Writes not allowed in dry-run mode
+    if (!storageHelper.dryRunInit || storageHelper.dryRun)
+        THROW(AssertError, WRITABLE_WHILE_DRYRUN);
+
     if (storageHelper.storageRepoWrite == NULL)
     {
         storageHelperInit();
@@ -498,6 +532,10 @@ storageSpoolWrite(void)
 {
     FUNCTION_TEST_VOID();
 
+    // Writes not allowed in dry-run mode
+    if (!storageHelper.dryRunInit || storageHelper.dryRun)
+        THROW(AssertError, WRITABLE_WHILE_DRYRUN);
+
     if (storageHelper.storageSpoolWrite == NULL)
     {
         storageHelperInit();
@@ -529,7 +567,7 @@ storageHelperFree(void)
     if (storageHelper.memContext != NULL)
         memContextFree(storageHelper.memContext);
 
-    memset(&storageHelper, 0, sizeof(storageHelper));
+    storageHelper = (struct StorageHelper){.memContext = NULL};
 
     FUNCTION_TEST_RETURN_VOID();
 }
