@@ -140,6 +140,9 @@ storagePosixInfo(THIS_VOID, const String *file, StorageInterfaceInfoParam param)
 }
 
 /**********************************************************************************************************************************/
+// Helper function to get info for a file if it exists.  This logic can't live directly in storagePosixInfoList() because there is
+// a race condition where a file might exist while listing the directory but it is gone before stat() can be called.  In order to
+// get complete test coverage this function must be split out.
 static void
 storagePosixInfoListEntry(
     StoragePosix *this, const String *path, const String *name, StorageInfoListCallback callback, void *callbackData)
@@ -292,7 +295,7 @@ storagePosixList(THIS_VOID, const String *path, StorageInterfaceListParam param)
                 }
 
                 // Move finished list up to the old context
-                strLstMove(result, MEM_CONTEXT_OLD());
+                strLstMove(result, memContextPrior());
             }
             MEM_CONTEXT_TEMP_END();
         }
@@ -386,13 +389,13 @@ storagePosixNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageIn
         FUNCTION_LOG_PARAM(STORAGE_POSIX, this);
         FUNCTION_LOG_PARAM(STRING, file);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
-        (void)param;                                                // No parameters are used
+        FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(file != NULL);
 
-    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadPosixNew(this, file, ignoreMissing));
+    FUNCTION_LOG_RETURN(STORAGE_READ, storageReadPosixNew(this, file, ignoreMissing, param.limit));
 }
 
 /**********************************************************************************************************************************/
@@ -632,7 +635,7 @@ New object
 ***********************************************************************************************************************************/
 static const StorageInterface storageInterfacePosix =
 {
-    .feature = (1 << storageFeaturePath | 1 << storageFeatureCompress),
+    .feature = 1 << storageFeaturePath | 1 << storageFeatureCompress | 1 << storageFeatureLimitRead,
 
     .exists = storagePosixExists,
     .info = storagePosixInfo,
@@ -677,8 +680,12 @@ storagePosixNewInternal(
     MEM_CONTEXT_NEW_BEGIN("StoragePosix")
     {
         StoragePosix *driver = memNew(sizeof(StoragePosix));
-        driver->memContext = MEM_CONTEXT_NEW();
-        driver->interface = storageInterfacePosix;
+
+        *driver = (StoragePosix)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .interface = storageInterfacePosix,
+        };
 
         // Disable path sync when not supported
         if (!pathSync)
