@@ -4,8 +4,7 @@ Remote Storage Protocol Handler
 #include "build.auto.h"
 
 #include "command/backup/pageChecksum.h"
-#include "common/compress/gzip/compress.h"
-#include "common/compress/gzip/decompress.h"
+#include "common/compress/helper.h"
 #include "common/crypto/cipherBlock.h"
 #include "common/crypto/hash.h"
 #include "common/debug.h"
@@ -72,10 +71,10 @@ storageRemoteFilterGroup(IoFilterGroup *filterGroup, const Variant *filterList)
         const String *filterKey = varStr(varLstGet(kvKeyList(filterKv), 0));
         const VariantList *filterParam = varVarLst(kvGet(filterKv, VARSTR(filterKey)));
 
-        if (strEq(filterKey, GZIP_COMPRESS_FILTER_TYPE_STR))
-            ioFilterGroupAdd(filterGroup, gzipCompressNewVar(filterParam));
-        else if (strEq(filterKey, GZIP_DECOMPRESS_FILTER_TYPE_STR))
-            ioFilterGroupAdd(filterGroup, gzipDecompressNewVar(filterParam));
+        IoFilter *filter = compressFilterVar(filterKey, filterParam);
+
+        if (filter != NULL)
+            ioFilterGroupAdd(filterGroup, filter);
         else if (strEq(filterKey, CIPHER_BLOCK_FILTER_TYPE_STR))
             ioFilterGroupAdd(filterGroup, cipherBlockNewVar(filterParam));
         else if (strEq(filterKey, CRYPTO_HASH_FILTER_TYPE_STR))
@@ -193,7 +192,7 @@ storageRemoteProtocol(const String *command, const VariantList *paramList, Proto
 
     // Determine which storage should be used
     const Storage *storage = protocolStorageTypeEnum(
-        cfgOptionStr(cfgOptType)) == protocolStorageTypeRepo ? storageRepo() : storagePg();
+        cfgOptionStr(cfgOptRemoteType)) == protocolStorageTypeRepo ? storageRepo() : storagePg();
     StorageInterface interface = storageInterface(storage);
     void *driver = storageDriver(storage);
 
@@ -247,10 +246,11 @@ storageRemoteProtocol(const String *command, const VariantList *paramList, Proto
         {
             // Create the read object
             IoRead *fileRead = storageReadIo(
-                storageInterfaceNewReadP(driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1))));
+                storageInterfaceNewReadP(
+                    driver, varStr(varLstGet(paramList, 0)), varBool(varLstGet(paramList, 1)), .limit = varLstGet(paramList, 2)));
 
             // Set filter group based on passed filters
-            storageRemoteFilterGroup(ioReadFilterGroup(fileRead), varLstGet(paramList, 2));
+            storageRemoteFilterGroup(ioReadFilterGroup(fileRead), varLstGet(paramList, 3));
 
             // Check if the file exists
             bool exists = ioReadOpen(fileRead);
