@@ -142,13 +142,15 @@ storageRemoteInfo(THIS_VOID, const String *file, StorageInterfaceInfoParam param
             // Acknowledge command completed
             protocolClientReadOutput(this->client, false);
 
-            // Duplicate strings into the calling context
-            memContextSwitch(MEM_CONTEXT_OLD());
-            result.name = strDup(result.name);
-            result.linkDestination = strDup(result.linkDestination);
-            result.user = strDup(result.user);
-            result.group = strDup(result.group);
-            memContextSwitch(MEM_CONTEXT_TEMP());
+            // Duplicate strings into the prior context
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                result.name = strDup(result.name);
+                result.linkDestination = strDup(result.linkDestination);
+                result.user = strDup(result.user);
+                result.group = strDup(result.group);
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
     }
     MEM_CONTEXT_TEMP_END();
@@ -187,18 +189,25 @@ storageRemoteInfoList(
 
         // Read list.  The list ends when there is a blank line -- this is safe even for file systems that allow blank filenames
         // since the filename is json-encoded so will always include quotes.
-        const String *name = protocolClientReadLine(this->client);
-
-        while (strSize(name) != 0)
+        MEM_CONTEXT_TEMP_RESET_BEGIN()
         {
-            StorageInfo info = {.exists = true, .name = jsonToStr(name)};
+            const String *name = protocolClientReadLine(this->client);
 
-            storageRemoteInfoParse(this->client, &info);
-            callback(callbackData, &info);
+            while (strSize(name) != 0)
+            {
+                StorageInfo info = {.exists = true, .name = jsonToStr(name)};
 
-            // Read the next item
-            name = protocolClientReadLine(this->client);
+                storageRemoteInfoParse(this->client, &info);
+                callback(callbackData, &info);
+
+                // Reset the memory context occasionally so we don't use too much memory or slow down processing
+                MEM_CONTEXT_TEMP_RESET(1000);
+
+                // Read the next item
+                name = protocolClientReadLine(this->client);
+            }
         }
+        MEM_CONTEXT_TEMP_END();
 
         // Acknowledge command completed
         result = varBool(protocolClientReadOutput(this->client, true));
@@ -231,7 +240,7 @@ storageRemoteList(THIS_VOID, const String *path, StorageInterfaceListParam param
         protocolCommandParamAdd(command, VARSTR(path));
         protocolCommandParamAdd(command, VARSTR(param.expression));
 
-        result = strLstMove(strLstNewVarLst(varVarLst(protocolClientExecute(this->client, command, true))), MEM_CONTEXT_OLD());
+        result = strLstMove(strLstNewVarLst(varVarLst(protocolClientExecute(this->client, command, true))), memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -249,6 +258,7 @@ storageRemoteNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageI
         FUNCTION_LOG_PARAM(STRING, file);
         FUNCTION_LOG_PARAM(BOOL, ignoreMissing);
         FUNCTION_LOG_PARAM(BOOL, param.compressible);
+        FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -257,7 +267,8 @@ storageRemoteNewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageI
     FUNCTION_LOG_RETURN(
         STORAGE_READ,
         storageReadRemoteNew(
-            this, this->client, file, ignoreMissing, this->compressLevel > 0 ? param.compressible : false, this->compressLevel));
+            this, this->client, file, ignoreMissing, this->compressLevel > 0 ? param.compressible : false, this->compressLevel,
+            param.limit));
 }
 
 /**********************************************************************************************************************************/
@@ -483,10 +494,14 @@ storageRemoteNew(
     MEM_CONTEXT_NEW_BEGIN("StorageRemote")
     {
         StorageRemote *driver = memNew(sizeof(StorageRemote));
-        driver->memContext = MEM_CONTEXT_NEW();
-        driver->client = client;
-        driver->compressLevel = compressLevel;
-        driver->interface = storageInterfaceRemote;
+
+        *driver = (StorageRemote)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .client = client,
+            .compressLevel = compressLevel,
+            .interface = storageInterfaceRemote,
+        };
 
         const String *path = NULL;
 
@@ -504,9 +519,11 @@ storageRemoteNew(
             protocolClientReadOutput(driver->client, false);
 
             // Dup path into parent context
-            memContextSwitch(MEM_CONTEXT_OLD());
-            path = strDup(path);
-            memContextSwitch(MEM_CONTEXT_TEMP());
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                path = strDup(path);
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
         MEM_CONTEXT_TEMP_END();
 
