@@ -30,7 +30,6 @@ struct Storage
     mode_t modeFile;
     mode_t modePath;
     bool write;
-    bool pathEnforce;
     StoragePathExpressionCallback *pathExpressionFunction;
 };
 
@@ -59,25 +58,28 @@ storageNew(
     ASSERT(strSize(path) >= 1 && strPtr(path)[0] == '/');
     ASSERT(driver != NULL);
     ASSERT(interface.exists != NULL);
+    ASSERT(interface.info != NULL);
     ASSERT(interface.list != NULL);
+    ASSERT(interface.infoList != NULL);
     ASSERT(interface.newRead != NULL);
     ASSERT(interface.newWrite != NULL);
     ASSERT(interface.pathRemove != NULL);
     ASSERT(interface.remove != NULL);
 
-    Storage *this = NULL;
-    this = (Storage *)memNew(sizeof(Storage));
-    this->memContext = memContextCurrent();
-    this->driver = driver;
-    this->interface = interface;
-    this->type = type;
+    Storage *this = (Storage *)memNew(sizeof(Storage));
 
-    this->path = strDup(path);
-    this->modeFile = modeFile;
-    this->modePath = modePath;
-    this->pathEnforce = true;
-    this->write = write;
-    this->pathExpressionFunction = pathExpressionFunction;
+    *this = (Storage)
+    {
+        .memContext = memContextCurrent(),
+        .driver = driver,
+        .interface = interface,
+        .type = type,
+        .path = strDup(path),
+        .modeFile = modeFile,
+        .modePath = modePath,
+        .write = write,
+        .pathExpressionFunction = pathExpressionFunction,
+    };
 
     // If path sync feature is enabled then path feature must be enabled
     CHECK(!storageFeature(this, storageFeaturePathSync) || storageFeature(this, storageFeaturePath));
@@ -228,7 +230,7 @@ storageGet(StorageRead *file, StorageGetParam param)
             }
 
             // Move buffer to parent context on success
-            bufMove(result, MEM_CONTEXT_OLD());
+            bufMove(result, memContextPrior());
         }
         MEM_CONTEXT_TEMP_END();
 
@@ -269,12 +271,14 @@ storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
         if (!result.exists && !param.ignoreMissing)
             THROW_SYS_ERROR_FMT(FileOpenError, STORAGE_ERROR_INFO_MISSING, strPtr(file));
 
-        // Dup the strings into the calling context
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result.linkDestination = strDup(result.linkDestination);
-        result.user = strDup(result.user);
-        result.group = strDup(result.group);
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        // Dup the strings into the prior context
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result.linkDestination = strDup(result.linkDestination);
+            result.user = strDup(result.user);
+            result.group = strDup(result.group);
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -533,7 +537,7 @@ storageList(const Storage *this, const String *pathExp, StorageListParam param)
         }
 
         // Move list up to the old context
-        result = strLstMove(result, MEM_CONTEXT_OLD());
+        result = strLstMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -593,9 +597,12 @@ storageNewRead(const Storage *this, const String *fileExp, StorageNewReadParam p
         FUNCTION_LOG_PARAM(STRING, fileExp);
         FUNCTION_LOG_PARAM(BOOL, param.ignoreMissing);
         FUNCTION_LOG_PARAM(BOOL, param.compressible);
+        FUNCTION_LOG_PARAM(VARIANT, param.limit);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
+    ASSERT(storageFeature(this, storageFeatureLimitRead) || param.limit == NULL);
+    ASSERT(param.limit == NULL || varType(param.limit) == varTypeUInt64);
 
     StorageRead *result = NULL;
 
@@ -603,8 +610,9 @@ storageNewRead(const Storage *this, const String *fileExp, StorageNewReadParam p
     {
         result = storageReadMove(
             storageInterfaceNewReadP(
-                this->driver, storagePathP(this, fileExp), param.ignoreMissing, .compressible = param.compressible),
-            MEM_CONTEXT_OLD());
+                this->driver, storagePathP(this, fileExp), param.ignoreMissing, .compressible = param.compressible,
+                .limit = param.limit),
+            memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -645,7 +653,7 @@ storageNewWrite(const Storage *this, const String *fileExp, StorageNewWriteParam
                 .modePath = param.modePath != 0 ? param.modePath : this->modePath, .user = param.user, .group = param.group,
                 .timeModified = param.timeModified, .createPath = !param.noCreatePath, .syncFile = !param.noSyncFile,
                 .syncPath = !param.noSyncPath, .atomic = !param.noAtomic, .compressible = param.compressible),
-            MEM_CONTEXT_OLD());
+            memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -681,7 +689,7 @@ storagePath(const Storage *this, const String *pathExp, StoragePathParam param)
             // Make sure the base storage path is contained within the path expression
             if (!strEqZ(this->path, "/"))
             {
-                if (this->pathEnforce && !param.noEnforce && (!strBeginsWith(pathExp, this->path) ||
+                if (!param.noEnforce && (!strBeginsWith(pathExp, this->path) ||
                     !(strSize(pathExp) == strSize(this->path) || *(strPtr(pathExp) + strSize(this->path)) == '/')))
                 {
                     THROW_FMT(AssertError, "absolute path '%s' is not in base path '%s'", strPtr(pathExp), strPtr(this->path));
@@ -966,22 +974,6 @@ storageInterface(const Storage *this)
     FUNCTION_TEST_RETURN(this->interface);
 }
 
-/***********************************************************************************************************************************
-Set whether absolute paths are required to be in the base path
-***********************************************************************************************************************************/
-void
-storagePathEnforceSet(Storage *this, bool enforce)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(STORAGE, this);
-        FUNCTION_TEST_PARAM(BOOL, enforce);
-    FUNCTION_TEST_END();
-
-    this->pathEnforce = enforce;
-
-    FUNCTION_TEST_RETURN_VOID();
-}
-
 /***********************************************************************************************************************************
 Get the storage type (posix, cifs, etc.)
 ***********************************************************************************************************************************/
