@@ -104,6 +104,9 @@ typedef struct StorageInterfaceNewReadParam
     // Is the file compressible?  This is useful when the file must be moved across a network and some temporary compression is
     // helpful.
     bool compressible;
+
+    // Limit bytes read from the file. NULL for no limit.
+    const Variant *limit;
 } StorageInterfaceNewReadParam;
 
 typedef StorageRead *StorageInterfaceNewRead(
@@ -302,10 +305,6 @@ Getters/Setters
 void *storageDriver(const Storage *this);
 StorageInterface storageInterface(const Storage *this);
 
-// The option is intended to be used only with the Perl interface since Perl is not tidy about where it reads.  It should be
-// removed when the Perl interface is removed.
-void storagePathEnforceSet(Storage *this, bool enforce);
-
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
