@@ -18,15 +18,15 @@ use File::Basename qw(dirname basename);
 use POSIX qw(ceil);
 use Time::HiRes qw(gettimeofday);
 
-use pgBackRest::DbVersion;
-use pgBackRest::Common::Exception;
-use pgBackRest::Common::Log;
-use pgBackRest::Common::String;
-use pgBackRest::Version;
+use pgBackRestDoc::Common::Exception;
+use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::Common::String;
+use pgBackRestDoc::ProjectInfo;
 
 use pgBackRestTest::Common::BuildTest;
 use pgBackRestTest::Common::ContainerTest;
 use pgBackRestTest::Common::CoverageTest;
+use pgBackRestTest::Common::DbVersion;
 use pgBackRestTest::Common::DefineTest;
 use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::ListTest;
@@ -65,6 +65,8 @@ sub new
         $self->{iTestMax},
         $self->{strLogLevel},
         $self->{strLogLevelTest},
+        $self->{strLogLevelTestFile},
+        $self->{bLogTimestamp},
         $self->{bLogForce},
         $self->{bShowOutputAsync},
         $self->{bNoCleanup},
@@ -97,6 +99,8 @@ sub new
             {name => 'iTestMax'},
             {name => 'strLogLevel'},
             {name => 'strLogLevelTest'},
+            {name => 'strLogLevelTestFile'},
+            {name => 'bLogTimestamp'},
             {name => 'bLogForce'},
             {name => 'bShowOutputAsync'},
             {name => 'bNoCleanup'},
@@ -162,7 +166,7 @@ sub run
             ', module=' . $self->{oTest}->{&TEST_MODULE} .
             ', test=' . $self->{oTest}->{&TEST_NAME} .
             (defined($self->{oTest}->{&TEST_RUN}) ? ', run=' . join(',', sort(@{$self->{oTest}->{&TEST_RUN}})) : '') .
-            (defined($self->{oTest}->{&TEST_DB}) ? ', db=' . $self->{oTest}->{&TEST_DB} : '') .
+            (defined($self->{oTest}->{&TEST_DB}) ? ', pg-version=' . $self->{oTest}->{&TEST_DB} : '') .
             ($self->{iTry} > 1 ? ' (retry ' . ($self->{iTry} - 1) . ')' : '');
 
         my $strImage = 'test-' . $self->{iVmIdx};
@@ -201,14 +205,16 @@ sub run
             {
                 if ($self->{oTest}->{&TEST_VM} ne VM_NONE)
                 {
+                    my $strBinPath = $self->{strTestPath} . '/bin/' . $self->{oTest}->{&TEST_VM} . '/' . PROJECT_EXE;
+
                     executeTest(
                         'docker run -itd -h ' . $self->{oTest}->{&TEST_VM} . "-test --name=${strImage}" .
                         " -v ${strHostTestPath}:${strVmTestPath}" .
                         ($self->{oTest}->{&TEST_C} ? " -v $self->{strGCovPath}:$self->{strGCovPath}" : '') .
                         ($self->{oTest}->{&TEST_C} ? " -v $self->{strDataPath}:$self->{strDataPath}" : '') .
-                        " -v $self->{strBackRestBase}:$self->{strBackRestBase} " .
-                        containerRepo() . ':' . $self->{oTest}->{&TEST_VM} .
-                        "-test",
+                        " -v $self->{strBackRestBase}:$self->{strBackRestBase}" .
+                        ($self->{oTest}->{&TEST_BIN_REQ} ? " -v ${strBinPath}:${strBinPath}:ro" : '') .
+                        ' ' . containerRepo() . ':' . $self->{oTest}->{&TEST_VM} . '-test',
                         {bSuppressStdErr => true});
                 }
 
@@ -219,25 +225,17 @@ sub run
                     if (!$rhBuildInit->{$self->{oTest}->{&TEST_VM}}{$self->{iVmIdx}})
                     {
                         executeTest(
-                            'rsync -rt --delete --exclude=*.o --exclude=test.c --exclude=test.gcno --exclude=LibC.h --exclude=xs' .
+                            'rsync -rt --delete --exclude=*.o --exclude=test.c --exclude=test.gcno ' .
                                 ' --exclude=test --exclude=buildflags --exclude=testflags --exclude=harnessflags' .
                                 ' --exclude=build.auto.h --exclude=build.auto.h.in --exclude=Makefile --exclude=Makefile.in' .
                                 ' --exclude=configure --exclude=configure.ac' .
                                 " $self->{strBackRestBase}/src/ $self->{strGCovPath} && " .
-                            "rsync -t $self->{strBackRestBase}/libc/LibC.h $self->{strGCovPath} && " .
-                            "rsync -rt --delete $self->{strBackRestBase}/libc/xs/ $self->{strGCovPath}/xs && " .
                             "rsync -rt --delete --exclude=*.o $self->{strBackRestBase}/test/src/ $self->{strGCovPath}/test");
                     }
 
                     # Build directory has been initialized
                     $rhBuildInit->{$self->{oTest}->{&TEST_VM}}{$self->{iVmIdx}} = true;
                 }
-
-                # If testing Perl code (or C code that calls Perl code) install bin and Perl C Library
-                if ($self->{oTest}->{&TEST_VM} ne VM_NONE && (!$self->{oTest}->{&TEST_C} || $self->{oTest}->{&TEST_PERL_REQ}))
-                {
-                    jobInstallC($self->{strBackRestBase}, $self->{oTest}->{&TEST_VM}, $strImage);
-                }
             }
         }
 
@@ -258,6 +256,8 @@ sub run
                 ($self->{oTest}->{&TEST_VM} ne VM_NONE  ? 'docker exec -i -u ' . TEST_USER . " ${strImage} " : '') .
                 "bash -l -c '" .
                 "cd $self->{strGCovPath} && " .
+                # Remove coverage data from last run
+                "rm -f test.gcda && " .
                 "make -j $self->{iBuildMax} -s 2>&1 &&" .
                 ($self->{oTest}->{&TEST_VM} ne VM_CO6 && $self->{bValgrindUnit} &&
                     $self->{oTest}->{&TEST_TYPE} ne TESTDEF_PERFORMANCE ?
@@ -279,6 +279,8 @@ sub run
                 $strCommandRunParam .
                 (defined($self->{oTest}->{&TEST_DB}) ? ' --pg-version=' . $self->{oTest}->{&TEST_DB} : '') .
                 ($self->{strLogLevel} ne lc(INFO) ? " --log-level=$self->{strLogLevel}" : '') .
+                ($self->{strLogLevelTestFile} ne lc(TRACE) ? " --log-level-test-file=$self->{strLogLevelTestFile}" : '') .
+                ($self->{bLogTimestamp} ? '' : ' --no-log-timestamp') .
                 ' --pgsql-bin=' . $self->{oTest}->{&TEST_PGSQL_BIN} .
                 ($self->{strTimeZone} ? " --tz='$self->{strTimeZone}'" : '') .
                 ($self->{bLogForce} ? ' --log-force' : '') .
@@ -378,8 +380,7 @@ sub run
                 }
 
                 # Determine where the project exe is located
-                my $strProjectExePath = $self->{oTest}->{&TEST_VM} eq VM_NONE ?
-                    "$self->{strBackRestBase}/test/.vagrant/bin/$self->{oTest}->{&TEST_VM}/src/" . PROJECT_EXE : PROJECT_EXE;
+                my $strProjectExePath = "$self->{strTestPath}/bin/$self->{oTest}->{&TEST_VM}/" . PROJECT_EXE;
 
                 # Is this test running in a container?
                 my $strContainer = $self->{oTest}->{&TEST_VM} eq VM_NONE ? 'false' : 'true';
@@ -397,6 +398,9 @@ sub run
                 $strTestC =~ s/\{\[C\_TEST\_REPO_PATH\]\}/$self->{strBackRestBase}/g;
                 $strTestC =~ s/\{\[C\_TEST\_SCALE\]\}/$self->{iScale}/g;
 
+                my $strLogTimestampC = $self->{bLogTimestamp} ? 'true' : 'false';
+                $strTestC =~ s/\{\[C\_TEST\_TIMING\]\}/$strLogTimestampC/g;
+
                 # Set timezone
                 if (defined($self->{strTimeZone}))
                 {
@@ -434,10 +438,23 @@ sub run
 
                 # Create build.auto.h
                 my $strBuildAutoH =
-                    "#define HAVE_LIBPERL\n";
+                    (vmWithLz4($self->{oTest}->{&TEST_VM}) ? '#define HAVE_LIBLZ4' : '') . "\n";
 
                 buildPutDiffers($self->{oStorageTest}, "$self->{strGCovPath}/" . BUILD_AUTO_H, $strBuildAutoH);
 
+                # Disable debug/coverage for performance and profile tests
+                my $bPerformance = $self->{oTest}->{&TEST_TYPE} eq TESTDEF_PERFORMANCE;
+
+                if ($bPerformance || $self->{bProfile})
+                {
+                    $self->{bDebug} = false;
+                    $self->{bDebugTestTrace} = false;
+                    $self->{bCoverageUnit} = false;
+                }
+
+                # When optimization is disabled add -ftree-coalesce-vars to make the compiler faster when available
+                my $strNoOptimizeFlags = '-O0' . ($self->{oTest}->{&TEST_VM} ne VM_U12 ? ' -ftree-coalesce-vars' : '');
+
                 # Determine which warnings are available
                 my $strWarningFlags =
                     '-Werror -Wfatal-errors -Wall -Wextra -Wwrite-strings -Wconversion -Wformat=2' .
@@ -451,20 +468,20 @@ sub run
 
                 # Flags that are common to all builds
                 my $strCommonFlags =
-                    '-I. -Itest -std=c99 -fPIC -g -Wno-clobbered -D_POSIX_C_SOURCE=200112L' .
-                        ' `perl -MExtUtils::Embed -e ccopts`' .
-                        ' `xml2-config --cflags`' . ($self->{bProfile} ? " -pg" : '') .
+                    '-I. -Itest -std=c99 -fPIC -g -Wno-clobbered -D_POSIX_C_SOURCE=200809L -D_FILE_OFFSET_BITS=64' .
+                        ' `pkg-config libxml-2.0 --cflags`' . ($self->{bProfile} ? " -pg" : '') .
                         ' -I`pg_config --includedir`' .
                     ($self->{oTest}->{&TEST_DEBUG_UNIT_SUPPRESS} ? '' : " -DDEBUG_UNIT") .
                     (vmWithBackTrace($self->{oTest}->{&TEST_VM}) && $self->{bBackTrace} ? ' -DWITH_BACKTRACE' : '') .
                     ($self->{oTest}->{&TEST_CDEF} ? " $self->{oTest}->{&TEST_CDEF}" : '') .
                     (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ? ' -DDEBUG_COVERAGE' : '') .
-                    ($self->{bDebug} && $self->{oTest}->{&TEST_TYPE} ne TESTDEF_PERFORMANCE ? '' : ' -DNDEBUG') .
-                    ($self->{bDebugTestTrace} && $self->{bDebug} ? ' -DDEBUG_TEST_TRACE' : '');
+                    ($self->{bDebug} ? '' : ' -DNDEBUG') .
+                    ($self->{bDebugTestTrace} && $self->{bDebug} ? ' -DDEBUG_TEST_TRACE' : '') .
+                    ($self->{oTest}->{&TEST_VM} eq VM_CO6 ? ' -DDEBUG_EXEC_TIME' : '');
 
                 # Flags used to build harness files
                 my $strHarnessFlags =
-                    '-O2' . ($self->{oTest}->{&TEST_VM} ne VM_U12 ? ' -ftree-coalesce-vars' : '') .
+                    ($self->{bOptimize} ? '-O2' : $strNoOptimizeFlags) .
                     ($self->{oTest}->{&TEST_CTESTDEF} ? " $self->{oTest}->{&TEST_CTESTDEF}" : '');
 
                 buildPutDiffers(
@@ -473,11 +490,9 @@ sub run
 
                 # Flags used to build test.c
                 my $strTestFlags =
-                    ($self->{bDebug} ? '-DDEBUG_TEST_TRACE ' : '') .
-                    ($self->{oTest}->{&TEST_VM} eq VM_F30 ? '-O2' : '-O0') .
-                    ($self->{oTest}->{&TEST_VM} ne VM_U12 ? ' -ftree-coalesce-vars' : '') .
-                    (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ?
-                        ' -fprofile-arcs -ftest-coverage' : '') .
+                    (($self->{bOptimize} && ($self->{bProfile} || $bPerformance)) ? '-O2' : $strNoOptimizeFlags) .
+                    (!$self->{bDebugTestTrace} && $self->{bDebug} ? ' -DDEBUG_TEST_TRACE' : '') .
+                    (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ? ' -fprofile-arcs -ftest-coverage' : '') .
                     ($self->{oTest}->{&TEST_CTESTDEF} ? " $self->{oTest}->{&TEST_CTESTDEF}" : '');
 
                 buildPutDiffers(
@@ -486,8 +501,7 @@ sub run
 
                 # Flags used to build all other files
                 my $strBuildFlags =
-                    ($self->{bOptimize} || $self->{oTest}->{&TEST_VM} eq VM_F30 ?
-                        '-O2' : '-O0' . ($self->{oTest}->{&TEST_VM} ne VM_U12 ? ' -ftree-coalesce-vars' : ''));
+                    ($self->{bOptimize} ? '-O2' : $strNoOptimizeFlags);
 
                 buildPutDiffers(
                     $self->{oStorageTest}, "$self->{strGCovPath}/buildflags",
@@ -502,9 +516,9 @@ sub run
                     "HARNESSFLAGS=${strHarnessFlags}\n" .
                     "TESTFLAGS=${strTestFlags}\n" .
                     "LDFLAGS=-lcrypto -lssl -lxml2 -lz" .
+                        (vmWithLz4($self->{oTest}->{&TEST_VM}) ? ' -llz4' : '') .
                         (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ? " -lgcov" : '') .
                         (vmWithBackTrace($self->{oTest}->{&TEST_VM}) && $self->{bBackTrace} ? ' -lbacktrace' : '') .
-                        " `perl -MExtUtils::Embed -e ldopts`\n" .
                     "\n" .
                     "SRCS=" . join(' ', @stryCFile) . "\n" .
                     "OBJS=\$(SRCS:.c=.o)\n" .
@@ -513,7 +527,7 @@ sub run
                     "\t\$(CC) -o test.bin \$(OBJS) test.o"  . ($self->{bProfile} ? " -pg" : '') . " \$(LDFLAGS)\n" .
                     "\n" .
                     "test.o: testflags test.c${strTestDepend}\n" .
-	                "\t\$(CC) \$(COMMONFLAGS) \$(WARNINGFLAGS) \$(TESTFLAGS) -c test.c\n";
+                    "\t\$(CC) \$(COMMONFLAGS) \$(WARNINGFLAGS) \$(TESTFLAGS) -c test.c\n";
 
                 # Build C file dependencies
                 foreach my $strCFile (@stryCFile)
@@ -605,138 +619,19 @@ sub end
                 ($self->{oTest}->{&TEST_VM} ne VM_NONE  ? 'docker exec -i -u ' . TEST_USER . " ${strImage} " : '') .
                     "gprof $self->{strGCovPath}/test.bin $self->{strGCovPath}/gmon.out > $self->{strGCovPath}/gprof.txt");
 
-            $self->{oStorageTest}->pathCreate("$self->{strBackRestBase}/test/profile", {strMode => '0750', bIgnoreExists => true});
+            $self->{oStorageTest}->pathCreate(
+                "$self->{strBackRestBase}/test/result/profile", {strMode => '0750', bIgnoreExists => true, bCreateParent => true});
             $self->{oStorageTest}->copy(
-                "$self->{strGCovPath}/gprof.txt", "$self->{strBackRestBase}/test/profile/gprof.txt");
+                "$self->{strGCovPath}/gprof.txt", "$self->{strBackRestBase}/test/result/profile/gprof.txt");
         }
 
         # If C code generate coverage info
         if ($iExitStatus == 0 && $self->{oTest}->{&TEST_C} && vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit})
         {
-            # Generate a list of files to cover
-            my $hTestCoverage =
-                (testDefModuleTest($self->{oTest}->{&TEST_MODULE}, $self->{oTest}->{&TEST_NAME}))->{&TESTDEF_COVERAGE};
-
-            my @stryCoveredModule;
-
-            foreach my $strModule (sort(keys(%{$hTestCoverage})))
-            {
-                push (@stryCoveredModule, $strModule);
-            }
-
-            push(
-                @stryCoveredModule,
-                "module/$self->{oTest}->{&TEST_MODULE}/" . testRunName($self->{oTest}->{&TEST_NAME}, false) . 'Test');
-
-            # Generate coverage reports for the modules
-            my $strLCovConf = $self->{strBackRestBase} . '/test/.vagrant/code/lcov.conf';
-            coverageLCovConfigGenerate($self->{oStorageTest}, $strLCovConf, $self->{bCoverageSummary});
-
-            my $strLCovExeBase = "lcov --config-file=${strLCovConf}";
-            my $strLCovOut = $self->{strGCovPath} . '/test.lcov';
-            my $strLCovOutTmp = $self->{strGCovPath} . '/test.tmp.lcov';
-
-            executeTest(
-                ($self->{oTest}->{&TEST_VM} ne VM_NONE  ? 'docker exec -i -u ' . TEST_USER . " ${strImage} " : '') .
-                "${strLCovExeBase} --capture --directory=$self->{strGCovPath} --o=${strLCovOut}");
-
-            # Generate coverage report for each module
-            foreach my $strModule (@stryCoveredModule)
-            {
-                my $strModuleName = testRunName($strModule, false);
-                my $strModuleOutName = $strModuleName;
-                my $bTest = false;
-
-                if ($strModuleOutName =~ /^module/mg)
-                {
-                    $strModuleOutName =~ s/^module/test/mg;
-                    $bTest = true;
-                }
-
-                # Disable branch coverage for test files
-                my $strLCovExe = $strLCovExeBase;
-
-                if ($bTest)
-                {
-                    $strLCovExe .= ' --rc lcov_branch_coverage=0';
-                }
-
-                # Generate lcov reports
-                my $strModulePath = $self->{strBackRestBase} . "/test/.vagrant/code/${strModuleOutName}";
-                my $strLCovFile = "${strModulePath}.lcov";
-                my $strLCovTotal = $self->{strBackRestBase} . "/test/.vagrant/code/all.lcov";
-
-                executeTest(
-                    "${strLCovExe} --extract=${strLCovOut} */${strModuleName}.c --o=${strLCovOutTmp}");
-
-                # Combine with prior run if there was one
-                if ($self->{oStorageTest}->exists($strLCovFile))
-                {
-                    my $strCoverage = ${$self->{oStorageTest}->get($strLCovOutTmp)};
-                    $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
-                    $self->{oStorageTest}->put($strLCovOutTmp, $strCoverage);
-
-                    executeTest(
-                        "${strLCovExe} --add-tracefile=${strLCovOutTmp} --add-tracefile=${strLCovFile} --o=${strLCovOutTmp}");
-                }
-
-                # Update source file
-                my $strCoverage = ${$self->{oStorageTest}->get($strLCovOutTmp)};
-
-                if (defined($strCoverage))
-                {
-                    if (!$bTest && $hTestCoverage->{$strModule} eq TESTDEF_COVERAGE_NOCODE)
-                    {
-                        confess &log(ERROR, "module '${strModule}' is marked 'no code' but has code");
-                    }
-
-                    # Get coverage info
-                    my $iTotalLines = (split(':', ($strCoverage =~ m/^LF:.*$/mg)[0]))[1] + 0;
-                    my $iCoveredLines = (split(':', ($strCoverage =~ m/^LH:.*$/mg)[0]))[1] + 0;
-
-                    my $iTotalBranches = 0;
-                    my $iCoveredBranches = 0;
-
-                    if ($strCoverage =~ /^BRF\:/mg && $strCoverage =~ /^BRH\:/mg)
-                    {
-                        # If this isn't here the statements below fail -- huh?
-                        my @match = $strCoverage =~ m/^BRF\:.*$/mg;
-
-                        $iTotalBranches = (split(':', ($strCoverage =~ m/^BRF:.*$/mg)[0]))[1] + 0;
-                        $iCoveredBranches = (split(':', ($strCoverage =~ m/^BRH:.*$/mg)[0]))[1] + 0;
-                    }
-
-                    # Report coverage if this is not a test or if the test does not have complete coverage
-                    if (!$bTest || $iTotalLines != $iCoveredLines || $iTotalBranches != $iCoveredBranches)
-                    {
-                        # Fix source file name
-                        $strCoverage =~ s/^SF\:.*$/SF:$strModulePath\.c/mg;
-
-                        $self->{oStorageTest}->put($strLCovFile, $strCoverage);
-
-                        if ($self->{oStorageTest}->exists($strLCovTotal))
-                        {
-                            executeTest(
-                                "${strLCovExe} --add-tracefile=${strLCovFile} --add-tracefile=${strLCovTotal} --o=${strLCovTotal}");
-                        }
-                        else
-                        {
-                            $self->{oStorageTest}->copy($strLCovFile, $strLCovTotal)
-                        }
-                    }
-                    else
-                    {
-                        $self->{oStorageTest}->remove($strLCovFile);
-                    }
-                }
-                else
-                {
-                    if ($hTestCoverage->{$strModule} ne TESTDEF_COVERAGE_NOCODE)
-                    {
-                        confess &log(ERROR, "module '${strModule}' is marked 'code' but has no code");
-                    }
-                }
-            }
+            coverageExtract(
+                $self->{oStorageTest}, $self->{oTest}->{&TEST_MODULE}, $self->{oTest}->{&TEST_NAME}, $self->{bCoverageSummary},
+                $self->{oTest}->{&TEST_VM} eq VM_NONE ? undef : $strImage, $self->{strTestPath}, "$self->{strTestPath}/temp",
+                $self->{strGCovPath}, $self->{strBackRestBase} . '/test/result');
         }
 
         # Record elapsed time
@@ -745,7 +640,7 @@ sub end
         # Output error
         if ($iExitStatus != 0)
         {
-            &log(ERROR, "${strTestDone} (err${iExitStatus}-${fTestElapsedTime}s)" .
+            &log(ERROR, "${strTestDone} (err${iExitStatus}" . ($self->{bLogTimestamp} ? "-${fTestElapsedTime}s)" : '') .
                  (defined($oExecDone->{strOutLog}) && !$self->{bShowOutputAsync} ?
                     ":\n\n" . trim($oExecDone->{strOutLog}) . "\n" : ''), undef, undef, 4);
             $bFail = true;
@@ -753,7 +648,7 @@ sub end
         # Output success
         else
         {
-            &log(INFO, "${strTestDone} (${fTestElapsedTime}s)".
+            &log(INFO, "${strTestDone}" . ($self->{bLogTimestamp} ? " (${fTestElapsedTime}s)" : '').
                  ($self->{bVmOut} && !$self->{bShowOutputAsync} ?
                      ":\n\n" . trim($oExecDone->{strOutLog}) . "\n" : ''), undef, undef, 4);
         }
@@ -782,27 +677,4 @@ sub end
     );
 }
 
-####################################################################################################################################
-# Install C binary and library
-####################################################################################################################################
-sub jobInstallC
-{
-    my $strBasePath = shift;
-    my $strVm = shift;
-    my $strImage = shift;
-
-    # Install Perl C Library
-    my $oVm = vmGet();
-    my $strBuildPath = "${strBasePath}/test/.vagrant/bin/${strVm}";
-    my $strBuildLibCPath = "${strBuildPath}/libc";
-    my $strBuildBinPath = "${strBuildPath}/src";
-
-    executeTest(
-        "docker exec -i -u root ${strImage} bash -c '" .
-        "cp ${strBuildBinPath}/" . PROJECT_EXE . ' /usr/bin/' . PROJECT_EXE . ' && ' .
-        'chmod 755 /usr/bin/' . PROJECT_EXE . "'");
-}
-
-push(@EXPORT, qw(jobInstallC));
-
 1;
