@@ -15,7 +15,6 @@ use Exporter qw(import);
 
 use pgBackRestDoc::Common::Exception;
 use pgBackRestDoc::Common::Log;
-use pgBackRestDoc::Common::String;
 
 use pgBackRestTest::Common::DbVersion;
 
@@ -30,23 +29,28 @@ use constant VM_DB_TEST                                             => 'db-test'
     push @EXPORT, qw(VM_DB_TEST);
 use constant VMDEF_DEBUG_INTEGRATION                                => 'debug-integration';
     push @EXPORT, qw(VMDEF_DEBUG_INTEGRATION);
-use constant VM_CONTROL_MTR                                         => 'control-mtr';
-    push @EXPORT, qw(VM_CONTROL_MTR);
+use constant VM_CONTROL_MASTER                                      => 'control-master';
+    push @EXPORT, qw(VM_CONTROL_MASTER);
 # Will coverage testing be run for C?
 use constant VMDEF_COVERAGE_C                                       => 'coverage-c';
 use constant VM_DEPRECATED                                          => 'deprecated';
     push @EXPORT, qw(VM_DEPRECATED);
 use constant VM_IMAGE                                               => 'image';
     push @EXPORT, qw(VM_IMAGE);
+use constant VM_OS                                                  => 'os';
+    push @EXPORT, qw(VM_OS);
 use constant VM_OS_BASE                                             => 'os-base';
     push @EXPORT, qw(VM_OS_BASE);
-use constant VMDEF_PG_REPO                                          => 'pg-repo';
-use constant VMDEF_PGSQL_BIN                                        => 'psql-bin';
+use constant VM_OS_REPO                                             => 'os-repo';
+    push @EXPORT, qw(VM_OS_REPO);
+use constant VMDEF_PGSQL_BIN                                        => 'pgsql-bin';
     push @EXPORT, qw(VMDEF_PGSQL_BIN);
+use constant VMDEF_LCOV_VERSION                                     => 'lcov-version';
+    push @EXPORT, qw(VMDEF_LCOV_VERSION);
+use constant VMDEF_WITH_BACKTRACE                                   => 'with-backtrace';
+    push @EXPORT, qw(VMDEF_WITH_BACKTRACE);
 use constant VMDEF_WITH_LZ4                                         => 'with-lz4';
     push @EXPORT, qw(VMDEF_WITH_LZ4);
-use constant VMDEF_WITH_ZST                                         => 'with-zst';
-    push @EXPORT, qw(VMDEF_WITH_ZST);
 
 ####################################################################################################################################
 # Valid OS base List
@@ -56,11 +60,19 @@ use constant VM_OS_BASE_DEBIAN                                      => 'debian';
 use constant VM_OS_BASE_RHEL                                        => 'rhel';
     push @EXPORT, qw(VM_OS_BASE_RHEL);
 
+####################################################################################################################################
+# Valid OS list
+####################################################################################################################################
+use constant VM_OS_CENTOS                                           => 'centos';
+    push @EXPORT, qw(VM_OS_CENTOS);
+use constant VM_OS_DEBIAN                                           => 'debian';
+    push @EXPORT, qw(VM_OS_DEBIAN);
+use constant VM_OS_UBUNTU                                           => 'ubuntu';
+    push @EXPORT, qw(VM_OS_DEBIAN);
+
 ####################################################################################################################################
 # Valid architecture list
 ####################################################################################################################################
-use constant VM_ARCH_AARCH64                                        => 'aarch64';
-    push @EXPORT, qw(VM_ARCH_AARCH64);
 use constant VM_ARCH_I386                                           => 'i386';
     push @EXPORT, qw(VM_ARCH_I386);
 use constant VM_ARCH_AMD64                                          => 'amd64';
@@ -75,19 +87,47 @@ use constant VM_ALL                                                 => 'all';
 use constant VM_NONE                                                => 'none';
     push @EXPORT, qw(VM_NONE);
 
-use constant VM_D11                                                 => 'd11';
-    push @EXPORT, qw(VM_D11);
-use constant VM_RH8                                                 => 'rh8';
-    push @EXPORT, qw(VM_RH8);
-use constant VM_F40                                                 => 'f40';
-    push @EXPORT, qw(VM_F40);
-use constant VM_U20                                                 => 'u20';
-    push @EXPORT, qw(VM_U20);
-use constant VM_U22                                                 => 'u22';
-    push @EXPORT, qw(VM_U22);
+use constant VM_CO6                                                 => 'co6';
+    push @EXPORT, qw(VM_CO6);
+use constant VM_CO7                                                 => 'co7';
+    push @EXPORT, qw(VM_CO7);
+use constant VM_F30                                                 => 'f30';
+    push @EXPORT, qw(VM_F30);
+use constant VM_U12                                                 => 'u12';
+    push @EXPORT, qw(VM_U12);
+use constant VM_U14                                                 => 'u14';
+    push @EXPORT, qw(VM_U14);
+use constant VM_U16                                                 => 'u16';
+    push @EXPORT, qw(VM_U16);
+use constant VM_U18                                                 => 'u18';
+    push @EXPORT, qw(VM_U18);
+use constant VM_U19                                                 => 'u19';
+    push @EXPORT, qw(VM_U19);
+use constant VM_D8                                                  => 'd8';
+    push @EXPORT, qw(VM_D8);
+use constant VM_D9                                                  => 'd9';
+    push @EXPORT, qw(VM_D9);
+
+# Defines the vm that will be used for expect testing
+use constant VM_EXPECT                                              => VM_CO7;
+    push @EXPORT, qw(VM_EXPECT);
+
+# Defines the host VM (the VM that the containers run in)
+use constant VM_HOST_DEFAULT                                        => VM_U18;
+    push @EXPORT, qw(VM_HOST_DEFAULT);
+
+# VM aliases for run matrices (numbered oldest to newest)
+use constant VM1                                                    => VM_CO6;
+    push @EXPORT, qw(VM1);
+use constant VM2                                                    => VM_U12;
+    push @EXPORT, qw(VM2);
+use constant VM3                                                    => VM_CO7;
+    push @EXPORT, qw(VM3);
+use constant VM4                                                    => VM_U18;
+    push @EXPORT, qw(VM4);
 
 # List of default test VMs
-use constant VM_LIST                                                => (VM_U20, VM_D11, VM_RH8, VM_U22);
+use constant VM_LIST                                                => (VM2, VM1, VM3, VM4);
     push @EXPORT, qw(VM_LIST);
 
 my $oyVm =
@@ -96,12 +136,11 @@ my $oyVm =
     &VM_NONE =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS => VM_OS_UBUNTU,
         &VM_ARCH => VM_ARCH_AMD64,
         &VMDEF_COVERAGE_C => true,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        &VMDEF_WITH_ZST => true,
-
         &VM_DB =>
         [
             PG_VERSION_10,
@@ -113,127 +152,288 @@ my $oyVm =
         ],
     },
 
-    # Debian 11
-    &VM_D11 =>
+    # CentOS 6
+    &VM_CO6 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_RHEL,
+        &VM_OS => VM_OS_CENTOS,
+        &VM_IMAGE => 'centos:6',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
+
+        &VM_DB =>
+        [
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_10,
+        ],
+    },
+
+    # CentOS 7
+    &VM_CO7 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_RHEL,
+        &VM_OS => VM_OS_CENTOS,
+        &VM_IMAGE => 'centos:7',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
+
+        &VMDEF_DEBUG_INTEGRATION => false,
+
+        &VM_DB =>
+        [
+            PG_VERSION_92,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_96,
+        ],
+    },
+
+    # Fedora 30
+    &VM_F30 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_RHEL,
+        &VM_OS => VM_OS_CENTOS,
+        &VM_IMAGE => 'fedora:30',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
+        &VMDEF_COVERAGE_C => true,
+
+        &VMDEF_DEBUG_INTEGRATION => false,
+
+        &VM_DB =>
+        [
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_11,
+        ],
+    },
+
+    # Debian 8
+    &VM_D8 =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_IMAGE => 'debian:11',
+        &VM_OS => VM_OS_DEBIAN,
+        &VM_OS_REPO => 'jessie',
+        &VM_IMAGE => 'debian:8',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
+
+        &VM_DB =>
+        [
+            PG_VERSION_84,
+            PG_VERSION_90,
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_95,
+        ],
+    },
+
+    # Debian 9
+    &VM_D9 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS => VM_OS_DEBIAN,
+        &VM_OS_REPO => 'stretch',
+        &VM_IMAGE => 'debian:9',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_92,
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_96,
+        ],
+    },
+
+    # Ubuntu 12.04
+    &VM_U12 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS => VM_OS_UBUNTU,
+        &VM_OS_REPO => 'precise',
+        &VM_IMAGE => 'i386/ubuntu:12.04',
         &VM_ARCH => VM_ARCH_I386,
-        &VMDEF_PG_REPO => false,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
-
-        &VMDEF_WITH_ZST => true,
+        &VMDEF_WITH_LZ4 => false,
 
         &VM_DB =>
         [
-            PG_VERSION_13,
+            PG_VERSION_83,
+            PG_VERSION_84,
+            PG_VERSION_90,
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
         ],
 
         &VM_DB_TEST =>
         [
-            PG_VERSION_13,
+            PG_VERSION_83,
+            PG_VERSION_84,
+            PG_VERSION_90,
+            PG_VERSION_93,
         ],
     },
 
-    # RHEL 8
-    &VM_RH8 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_RHEL,
-        &VM_IMAGE => 'rockylinux/rockylinux:8',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
-
-        &VMDEF_DEBUG_INTEGRATION => false,
-        &VMDEF_WITH_ZST => true,
-
-        &VM_DB =>
-        [
-            PG_VERSION_13,
-            PG_VERSION_14,
-            PG_VERSION_15,
-            PG_VERSION_16,
-            PG_VERSION_17,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_14,
-            PG_VERSION_15,
-            PG_VERSION_16,
-        ],
-    },
-
-    # Fedora 40
-    &VM_F40 =>
-    {
-        &VM_OS_BASE => VM_OS_BASE_RHEL,
-        &VM_IMAGE => 'fedora:40',
-        &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_PGSQL_BIN => '/usr/pgsql-{[version]}/bin',
-        &VMDEF_COVERAGE_C => true,
-
-        &VMDEF_DEBUG_INTEGRATION => false,
-        &VMDEF_WITH_ZST => true,
-
-        &VM_DB =>
-        [
-            PG_VERSION_13,
-            PG_VERSION_14,
-            PG_VERSION_15,
-            PG_VERSION_16,
-            PG_VERSION_17,
-        ],
-
-        &VM_DB_TEST =>
-        [
-            PG_VERSION_15,
-        ],
-    },
-
-    # Ubuntu 20.04
-    &VM_U20 =>
+    # Ubuntu 14.04
+    &VM_U14 =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_IMAGE => 'ubuntu:20.04',
+        &VM_OS => VM_OS_UBUNTU,
+        &VM_OS_REPO => 'trusty',
+        &VM_IMAGE => 'ubuntu:14.04',
         &VM_ARCH => VM_ARCH_AMD64,
-        &VMDEF_COVERAGE_C => true,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        &VMDEF_WITH_ZST => true,
-
         &VM_DB =>
         [
+            PG_VERSION_84,
+            PG_VERSION_90,
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
             PG_VERSION_94,
             PG_VERSION_95,
             PG_VERSION_96,
             PG_VERSION_10,
             PG_VERSION_11,
             PG_VERSION_12,
-            PG_VERSION_13,
-            PG_VERSION_14,
-            PG_VERSION_15,
-            PG_VERSION_16,
-            PG_VERSION_17,
         ],
 
-        &VM_DB_TEST =>
+        &VM_DB =>
         [
             PG_VERSION_94,
-            PG_VERSION_95,
-            PG_VERSION_96,
         ],
     },
 
-    # Ubuntu 22.04
-    &VM_U22 =>
+    # Ubuntu 16.04
+    &VM_U16 =>
     {
         &VM_OS_BASE => VM_OS_BASE_DEBIAN,
-        &VM_IMAGE => 'ubuntu:22.04',
+        &VM_OS => VM_OS_UBUNTU,
+        &VM_OS_REPO => 'xenial',
+        &VM_IMAGE => 'ubuntu:16.04',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
+
+        &VMDEF_WITH_BACKTRACE => true,
+
+        &VM_DB =>
+        [
+            PG_VERSION_91,
+            PG_VERSION_92,
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_94,
+            PG_VERSION_95,
+        ],
+    },
+
+    # Ubuntu 18.04
+    &VM_U18 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS => VM_OS_UBUNTU,
+        &VM_OS_REPO => 'bionic',
+        &VM_IMAGE => 'ubuntu:18.04',
         &VM_ARCH => VM_ARCH_AMD64,
         &VMDEF_COVERAGE_C => true,
         &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
 
-        &VMDEF_WITH_ZST => true,
+        &VMDEF_WITH_BACKTRACE => true,
+
+        &VM_DB =>
+        [
+            PG_VERSION_93,
+            PG_VERSION_94,
+            PG_VERSION_95,
+            PG_VERSION_96,
+            PG_VERSION_10,
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+
+        &VM_DB_TEST =>
+        [
+            PG_VERSION_11,
+            PG_VERSION_12,
+        ],
+    },
+
+    # Ubuntu 19.04
+    &VM_U19 =>
+    {
+        &VM_OS_BASE => VM_OS_BASE_DEBIAN,
+        &VM_OS => VM_OS_UBUNTU,
+        &VM_OS_REPO => 'disco',
+        &VM_IMAGE => 'ubuntu:19.04',
+        &VM_ARCH => VM_ARCH_AMD64,
+        &VMDEF_COVERAGE_C => true,
+        &VMDEF_PGSQL_BIN => '/usr/lib/postgresql/{[version]}/bin',
+
+        &VMDEF_LCOV_VERSION => '1.14',
+        &VMDEF_WITH_BACKTRACE => true,
 
         &VM_DB =>
         [
@@ -243,19 +443,11 @@ my $oyVm =
             PG_VERSION_10,
             PG_VERSION_11,
             PG_VERSION_12,
-            PG_VERSION_13,
-            PG_VERSION_14,
-            PG_VERSION_15,
-            PG_VERSION_16,
-            PG_VERSION_17,
         ],
 
         &VM_DB_TEST =>
         [
-            PG_VERSION_10,
-            PG_VERSION_11,
             PG_VERSION_12,
-            PG_VERSION_17,
         ],
     },
 };
@@ -329,23 +521,21 @@ sub vmValid
 push @EXPORT, qw(vmValid);
 
 ####################################################################################################################################
-# vmPgRepo
+# Which vm to use for the test matrix.  If one of the standard four, then use that, else use VM4.
 ####################################################################################################################################
-sub vmPgRepo
+sub vmTest
 {
     my $strVm = shift;
 
-    vmValid($strVm);
-
-    if (!defined($oyVm->{$strVm}{&VMDEF_PG_REPO}))
+    if (grep(/^$strVm$/, VM_LIST))
     {
-        return true;
+        return $strVm;
     }
 
-    return $oyVm->{$strVm}{&VMDEF_PG_REPO};
+    return VM4;
 }
 
-push @EXPORT, qw(vmPgRepo);
+push @EXPORT, qw(vmTest);
 
 ####################################################################################################################################
 # vmGet
@@ -389,33 +579,22 @@ sub vmArchBits
 {
     my $strVm = shift;
 
-    return ($oyVm->{$strVm}{&VM_ARCH} eq VM_ARCH_I386 ? 32 : 64);
+    return ($oyVm->{$strVm}{&VM_ARCH} eq VM_ARCH_AMD64 ? 64 : 32);
 }
 
 push @EXPORT, qw(vmArchBits);
 
 ####################################################################################################################################
-# Get host architecture
+# Does the VM support libbacktrace?
 ####################################################################################################################################
-my $strHostArch = undef;
-
-sub hostArch
+sub vmWithBackTrace
 {
-    if (!defined($strHostArch))
-    {
-        $strHostArch = trim(`uname -m`);
+    my $strVm = shift;
 
-        # Mac M1 reports arm64 but we generally need aarch64 (which Linux reports)
-        if ($strHostArch eq 'arm64')
-        {
-            $strHostArch = 'aarch64';
-        }
-    }
-
-    return $strHostArch;
+    return ($oyVm->{$strVm}{&VMDEF_WITH_BACKTRACE} ? true : false);
 }
 
-push @EXPORT, qw(hostArch);
+push @EXPORT, qw(vmWithBackTrace);
 
 ####################################################################################################################################
 # Does the VM support liblz4?
@@ -429,18 +608,6 @@ sub vmWithLz4
 
 push @EXPORT, qw(vmWithLz4);
 
-####################################################################################################################################
-# Does the VM support liblzst?
-####################################################################################################################################
-sub vmWithZst
-{
-    my $strVm = shift;
-
-    return (defined($oyVm->{$strVm}{&VMDEF_WITH_ZST}) ? $oyVm->{$strVm}{&VMDEF_WITH_ZST} : false);
-}
-
-push @EXPORT, qw(vmWithZst);
-
 ####################################################################################################################################
 # Will integration tests be run in debug mode?
 ####################################################################################################################################
