@@ -1,7 +1,7 @@
 /***********************************************************************************************************************************
 Test Archive Get Command
 ***********************************************************************************************************************************/
-#include "common/compress/gzip/compress.h"
+#include "common/compress/helper.h"
 #include "common/harnessConfig.h"
 #include "common/harnessFork.h"
 #include "common/io/bufferRead.h"
@@ -89,8 +89,8 @@ testRun(void)
                     "repo/archive/test1/10-2/8765432187654321/876543218765432187654321-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa")),
             NULL);
 
-        TEST_RESULT_STR(
-            strPtr(archiveGetCheck(strNew("876543218765432187654321"), cipherTypeNone, NULL).archiveFileActual),
+        TEST_RESULT_STR_Z(
+            archiveGetCheck(strNew("876543218765432187654321"), cipherTypeNone, NULL).archiveFileActual,
             "10-2/8765432187654321/876543218765432187654321-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", "segment found");
 
         // Write segment into an newer archive path
@@ -102,8 +102,8 @@ testRun(void)
                     "repo/archive/test1/10-4/8765432187654321/876543218765432187654321-bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb")),
             NULL);
 
-        TEST_RESULT_STR(
-            strPtr(archiveGetCheck(strNew("876543218765432187654321"), cipherTypeNone, NULL).archiveFileActual),
+        TEST_RESULT_STR_Z(
+            archiveGetCheck(strNew("876543218765432187654321"), cipherTypeNone, NULL).archiveFileActual,
             "10-4/8765432187654321/876543218765432187654321-bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb", "newer segment found");
 
         // Get history file
@@ -113,11 +113,9 @@ testRun(void)
 
         storagePutP(storageNewWriteP(storageTest, strNew("repo/archive/test1/10-4/00000009.history")), NULL);
 
-        TEST_RESULT_STR(
-            strPtr(
-                archiveGetCheck(
-                    strNew("00000009.history"), cipherTypeNone, NULL).archiveFileActual), "10-4/00000009.history",
-                    "history file found");
+        TEST_RESULT_STR_Z(
+            archiveGetCheck(strNew("00000009.history"), cipherTypeNone, NULL).archiveFileActual, "10-4/00000009.history",
+            "history file found");
     }
 
     // *****************************************************************************************************************************
@@ -170,7 +168,7 @@ testRun(void)
         TEST_RESULT_INT(
             archiveGetFile(storageTest, archiveFile, walDestination, false, cipherTypeNone, NULL), 0, "WAL segment copied");
         TEST_RESULT_BOOL(storageExistsP(storageTest, walDestination), true, "  check exists");
-        TEST_RESULT_INT(storageInfoP(storageTest, walDestination).size, 16 * 1024 * 1024, "  check size");
+        TEST_RESULT_UINT(storageInfoP(storageTest, walDestination).size, 16 * 1024 * 1024, "  check size");
 
         storageRemoveP(
             storageTest,
@@ -204,7 +202,7 @@ testRun(void)
                 "repo/archive/test1/10-1/01ABCDEF01ABCDEF/01ABCDEF01ABCDEF01ABCDEF-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa.gz"));
 
         IoFilterGroup *filterGroup = ioWriteFilterGroup(storageWriteIo(destination));
-        ioFilterGroupAdd(filterGroup, gzipCompressNew(3, false));
+        ioFilterGroupAdd(filterGroup, compressFilter(compressTypeGz, 3));
         ioFilterGroupAdd(
             filterGroup, cipherBlockNew(cipherModeEncrypt, cipherTypeAes256Cbc, BUFSTRDEF("worstpassphraseever"), NULL));
         storagePutP(destination, buffer);
@@ -213,7 +211,7 @@ testRun(void)
             archiveGetFile(
                 storageTest, archiveFile, walDestination, false, cipherTypeAes256Cbc, strNew("12345678")), 0, "WAL segment copied");
         TEST_RESULT_BOOL(storageExistsP(storageTest, walDestination), true, "  check exists");
-        TEST_RESULT_INT(storageInfoP(storageTest, walDestination).size, 16 * 1024 * 1024, "  check size");
+        TEST_RESULT_UINT(storageInfoP(storageTest, walDestination).size, 16 * 1024 * 1024, "  check size");
 
         // Check protocol function directly
         // -------------------------------------------------------------------------------------------------------------------------
@@ -222,9 +220,10 @@ testRun(void)
         strLstAdd(argList, strNewFmt("--repo1-path=%s/repo", testPath()));
         strLstAdd(argList, strNewFmt("--pg1-path=%s/db", testPath()));
         strLstAdd(argList, strNewFmt("--spool-path=%s/spool", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
         strLstAddZ(argList, "--repo1-cipher-type=aes-256-cbc");
         setenv("PGBACKREST_REPO1_CIPHER_PASS", "12345678", true);
-        harnessCfgLoad(cfgCmdArchiveGetAsync, argList);
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
         unsetenv("PGBACKREST_REPO1_CIPHER_PASS");
 
         storagePathCreateP(storageTest, strNew("spool/archive/test1/in"));
@@ -234,7 +233,7 @@ testRun(void)
 
         TEST_RESULT_BOOL(
             archiveGetProtocol(PROTOCOL_COMMAND_ARCHIVE_GET_STR, paramList, server), true, "protocol archive get");
-        TEST_RESULT_STR(strPtr(strNewBuf(serverWrite)), "{\"out\":0}\n", "check result");
+        TEST_RESULT_STR_Z(strNewBuf(serverWrite), "{\"out\":0}\n", "check result");
         TEST_RESULT_BOOL(
             storageExistsP(storageTest, strNewFmt("spool/archive/test1/in/%s", strPtr(archiveFile))), true, "  check exists");
 
@@ -264,15 +263,15 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         storagePathCreateP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN));
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(queueNeed(strNew("000000010000000100000001"), false, queueSize, walSegmentSize, PG_VERSION_92), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(queueNeed(strNew("000000010000000100000001"), false, queueSize, walSegmentSize, PG_VERSION_92), "|"),
             "000000010000000100000001|000000010000000100000002", "queue size smaller than min");
 
         // -------------------------------------------------------------------------------------------------------------------------
         queueSize = (16 * 1024 * 1024) * 3;
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(queueNeed(strNew("000000010000000100000001"), false, queueSize, walSegmentSize, PG_VERSION_92), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(queueNeed(strNew("000000010000000100000001"), false, queueSize, walSegmentSize, PG_VERSION_92), "|"),
             "000000010000000100000001|000000010000000100000002|000000010000000100000003", "empty queue");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -286,13 +285,13 @@ testRun(void)
             storageNewWriteP(
                 storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN "/0000000100000001000000FF")), walSegmentBuffer);
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(queueNeed(strNew("0000000100000001000000FE"), false, queueSize, walSegmentSize, PG_VERSION_92), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(queueNeed(strNew("0000000100000001000000FE"), false, queueSize, walSegmentSize, PG_VERSION_92), "|"),
             "000000010000000200000000|000000010000000200000001", "queue has wal < 9.3");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(storageListP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN)), "|")),
-            "0000000100000001000000FE", "check queue");
+        TEST_RESULT_STR_Z(
+            strLstJoin(storageListP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN)), "|"), "0000000100000001000000FE",
+            "check queue");
 
         // -------------------------------------------------------------------------------------------------------------------------
         walSegmentSize = 1024 * 1024;
@@ -306,12 +305,12 @@ testRun(void)
             storageNewWriteP(
                 storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN "/000000010000000A00000FFF")), walSegmentBuffer);
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(queueNeed(strNew("000000010000000A00000FFD"), true, queueSize, walSegmentSize, PG_VERSION_11), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(queueNeed(strNew("000000010000000A00000FFD"), true, queueSize, walSegmentSize, PG_VERSION_11), "|"),
             "000000010000000B00000000|000000010000000B00000001|000000010000000B00000002", "queue has wal >= 9.3");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_IN)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_IN)), sortOrderAsc), "|"),
             "000000010000000A00000FFE|000000010000000A00000FFF", "check queue");
     }
 
@@ -325,11 +324,27 @@ testRun(void)
         strLstAdd(argCleanList, strNewFmt("--pg1-path=%s/pg", testPath()));
         strLstAdd(argCleanList, strNewFmt("--repo1-path=%s/repo", testPath()));
         strLstAdd(argCleanList, strNewFmt("--spool-path=%s/spool", testPath()));
+        strLstAddZ(argCleanList, "--" CFGOPT_ARCHIVE_ASYNC);
         strLstAddZ(argCleanList, "--stanza=test2");
-        harnessCfgLoad(cfgCmdArchiveGetAsync, argCleanList);
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argCleanList);
 
         TEST_ERROR(cmdArchiveGetAsync(), ParamInvalidError, "at least one wal segment is required");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("command must be run on the pg host");
+
+        StringList *argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_PG1_HOST "=host");
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/pg");
+        strLstAddZ(argList, "--" CFGOPT_REPO1_PATH "=/repo");
+        strLstAddZ(argList, "--" CFGOPT_SPOOL_PATH "=/spool");
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test2");
+        strLstAddZ(argList, "000000010000000100000001");
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
+
+        TEST_ERROR(cmdArchiveGetAsync(), HostInvalidError, "archive-get command must be run on the PostgreSQL host");
+
         // Create pg_control file and archive.info
         // -------------------------------------------------------------------------------------------------------------------------
         storagePutP(
@@ -347,9 +362,9 @@ testRun(void)
 
         // Get a single segment
         // -------------------------------------------------------------------------------------------------------------------------
-        StringList *argList = strLstDup(argCleanList);
+        argList = strLstDup(argCleanList);
         strLstAddZ(argList, "000000010000000100000001");
-        harnessCfgLoad(cfgCmdArchiveGetAsync, argList);
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
 
         storagePathCreateP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN));
 
@@ -378,7 +393,7 @@ testRun(void)
         strLstAddZ(argList, "000000010000000100000001");
         strLstAddZ(argList, "000000010000000100000002");
         strLstAddZ(argList, "000000010000000100000003");
-        harnessCfgLoad(cfgCmdArchiveGetAsync, argList);
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
 
         storagePathCreateP(storageSpoolWrite(), strNew(STORAGE_SPOOL_ARCHIVE_IN));
 
@@ -440,8 +455,9 @@ testRun(void)
         strLstAdd(argList, strNewFmt("--pg1-path=%s/pg", testPath()));
         strLstAdd(argList, strNewFmt("--repo1-path=%s/repo", testPath()));
         strLstAdd(argList, strNewFmt("--spool-path=%s/spool", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
         strLstAddZ(argList, "--stanza=test2");
-        strLstAddZ(argList, "archive-get-async");
+        strLstAddZ(argList, CFGCMD_ARCHIVE_GET ":" CONFIG_COMMAND_ROLE_ASYNC);
         strLstAddZ(argList, "000000010000000100000001");
         strLstAddZ(argList, "000000010000000100000002");
         strLstAddZ(argList, "000000010000000100000003");
@@ -463,11 +479,8 @@ testRun(void)
         TEST_RESULT_BOOL(
             storageExistsP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_IN "/000000010000000100000003.error")), false,
             "check 000000010000000100000003.error not in spool");
-        TEST_RESULT_STR(
-            strPtr(
-                strNewBuf(
-                    storageGetP(
-                        storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_IN "/global.error"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_IN "/global.error")))),
             "102\nlocal-1 process terminated unexpectedly [102]: unable to execute 'pgbackrest-bogus': "
                 "[2] No such file or directory",
             "check global error");
@@ -476,7 +489,21 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("cmdArchiveGet()"))
     {
+        TEST_TITLE("command must be run on the pg host");
+
         StringList *argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_PG1_HOST "=host");
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/pg");
+        strLstAddZ(argList, "--" CFGOPT_REPO1_PATH "=/repo");
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test2");
+        strLstAddZ(argList, "000000010000000100000001");
+        strLstAddZ(argList, "pg_wal/000000010000000100000001");
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleDefault, argList);
+
+        TEST_ERROR(cmdArchiveGet(), HostInvalidError, "archive-get command must be run on the PostgreSQL host");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
         strLstAddZ(argList, "pgbackrest-bogus");                    // Break this until async tests are setup correctly
         strLstAddZ(argList, "--archive-timeout=1");
         strLstAdd(argList, strNewFmt("--lock-path=%s/lock", testPath()));
