@@ -111,7 +111,11 @@ ioTestFilterSizeNew(const char *type)
     MEM_CONTEXT_NEW_BEGIN("IoTestFilterSize")
     {
         IoTestFilterSize *driver = memNew(sizeof(IoTestFilterSize));
-        driver->memContext = MEM_CONTEXT_NEW();
+
+        *driver = (IoTestFilterSize)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+        };
 
         this = ioFilterNewP(strNew(type), driver, NULL, .in = ioTestFilterSizeProcess, .result = ioTestFilterSizeResult);
     }
@@ -212,11 +216,15 @@ ioTestFilterMultiplyNew(const char *type, unsigned int multiplier, unsigned int
     MEM_CONTEXT_NEW_BEGIN("IoTestFilterMultiply")
     {
         IoTestFilterMultiply *driver = memNew(sizeof(IoTestFilterMultiply));
-        driver->memContext = MEM_CONTEXT_NEW();
-        driver->bufferFilter = ioBufferNew();
-        driver->multiplier = multiplier;
-        driver->flushTotal = flushTotal;
-        driver->flushChar = flushChar;
+
+        *driver = (IoTestFilterMultiply)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .bufferFilter = ioBufferNew(),
+            .multiplier = multiplier,
+            .flushTotal = flushTotal,
+            .flushChar = flushChar,
+        };
 
         VariantList *paramList = varLstNew();
         varLstAdd(paramList, varNewStrZ(type));
@@ -243,9 +251,9 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("ioBufferSize() and ioBufferSizeSet()"))
     {
-        TEST_RESULT_SIZE(ioBufferSize(), 65536, "check initial buffer size");
+        TEST_RESULT_UINT(ioBufferSize(), 65536, "check initial buffer size");
         TEST_RESULT_VOID(ioBufferSizeSet(16384), "set buffer size");
-        TEST_RESULT_SIZE(ioBufferSize(), 16384, "check buffer size");
+        TEST_RESULT_UINT(ioBufferSize(), 16384, "check buffer size");
     }
 
     // *****************************************************************************************************************************
@@ -266,7 +274,7 @@ testRun(void)
             "create io read object");
 
         TEST_RESULT_BOOL(ioReadOpen(read), true, "    open io object");
-        TEST_RESULT_SIZE(ioRead(read, buffer), 2, "    read 2 bytes");
+        TEST_RESULT_UINT(ioRead(read, buffer), 2, "    read 2 bytes");
         TEST_RESULT_BOOL(ioReadEof(read), false, "    no eof");
         TEST_RESULT_VOID(ioReadClose(read), "    close io object");
         TEST_RESULT_BOOL(testIoReadCloseCalled, true, "    check io object closed");
@@ -283,7 +291,7 @@ testRun(void)
         TEST_ASSIGN(bufferRead, ioBufferReadNew(bufferOriginal), "create empty buffer read object");
         TEST_RESULT_BOOL(ioReadOpen(bufferRead), true, "    open");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), false, "    not eof");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 0, "    read 0 bytes");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 0, "    read 0 bytes");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), true, "    now eof");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -308,36 +316,36 @@ testRun(void)
         IoFilter *bufferFilter = ioBufferNew();
         TEST_RESULT_VOID(ioFilterGroupAdd(ioReadFilterGroup(bufferRead), bufferFilter), "    add filter to filter group");
         TEST_RESULT_PTR(ioFilterMove(NULL, memContextTop()), NULL, "    move NULL filter to top context");
-        TEST_RESULT_STR(
-            strPtr(jsonFromVar(ioFilterGroupParamAll(ioReadFilterGroup(bufferRead)))),
+        TEST_RESULT_STR_Z(
+            jsonFromVar(ioFilterGroupParamAll(ioReadFilterGroup(bufferRead))),
             "[{\"size\":null},{\"double\":[\"double\",2,3]},{\"size\":null},{\"buffer\":null}]", "    check filter params");
 
         TEST_RESULT_BOOL(ioReadOpen(bufferRead), true, "    open");
         TEST_RESULT_INT(ioReadHandle(bufferRead), -1, "    handle invalid");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), false, "    not eof");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 0, "    read 0 bytes (full buffer)");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "11", "    check read");
-        TEST_RESULT_STR(strPtr(ioFilterType(sizeFilter)), "size", "check filter type");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 0, "    read 0 bytes (full buffer)");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "11", "    check read");
+        TEST_RESULT_STR_Z(ioFilterType(sizeFilter), "size", "check filter type");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), false, "    not eof");
 
         TEST_RESULT_VOID(bufUsedZero(buffer), "    zero buffer");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "22", "    check read");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "22", "    check read");
 
         TEST_ASSIGN(buffer, bufNew(3), "change output buffer size to 3");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 3, "    read 3 bytes");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "33X", "    check read");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 3, "    read 3 bytes");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "33X", "    check read");
 
         TEST_RESULT_VOID(bufUsedZero(buffer), "    zero buffer");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "XX", "    check read");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 2, "    read 2 bytes");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "XX", "    check read");
         TEST_RESULT_BOOL(ioReadEof(bufferRead), true, "    eof");
-        TEST_RESULT_BOOL(ioBufferRead(ioReadDriver(bufferRead), buffer, true), 0, "    eof from driver");
-        TEST_RESULT_SIZE(ioRead(bufferRead, buffer), 0, "    read 0 bytes");
+        TEST_RESULT_UINT(ioBufferRead(ioReadDriver(bufferRead), buffer, true), 0, "    eof from driver");
+        TEST_RESULT_UINT(ioRead(bufferRead, buffer), 0, "    read 0 bytes");
         TEST_RESULT_VOID(ioReadClose(bufferRead), " close buffer read object");
-        TEST_RESULT_STR(
-            strPtr(jsonFromVar(ioFilterGroupResultAll(ioReadFilterGroup(bufferRead)))),
+        TEST_RESULT_STR_Z(
+            jsonFromVar(ioFilterGroupResultAll(ioReadFilterGroup(bufferRead))),
             "{\"buffer\":null,\"double\":null,\"size\":[3,9]}",
             "    check filter result all");
 
@@ -379,7 +387,7 @@ testRun(void)
             "    add filter that produces output with no input");
         TEST_RESULT_BOOL(ioReadOpen(bufferRead), true, "    open read");
         TEST_RESULT_UINT(ioRead(bufferRead, buffer), 5, "    read 5 chars");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "YYYYY", "    check buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "YYYYY", "    check buffer");
 
         // Mixed line and buffer read
         // -------------------------------------------------------------------------------------------------------------------------
@@ -389,41 +397,41 @@ testRun(void)
         buffer = bufNew(3);
 
         // Start with a buffer read
-        TEST_RESULT_INT(ioRead(read, buffer), 3, "read buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AAA", "    check buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 3, "read buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AAA", "    check buffer");
 
         // Do line reads of various lengths
-        TEST_RESULT_STR(strPtr(ioReadLine(read)), "123", "read line");
-        TEST_RESULT_STR(strPtr(ioReadLine(read)), "1234", "read line");
-        TEST_RESULT_STR(strPtr(ioReadLine(read)), "", "read line");
-        TEST_RESULT_STR(strPtr(ioReadLine(read)), "12", "read line");
+        TEST_RESULT_STR_Z(ioReadLine(read), "123", "read line");
+        TEST_RESULT_STR_Z(ioReadLine(read), "1234", "read line");
+        TEST_RESULT_STR_Z(ioReadLine(read), "", "read line");
+        TEST_RESULT_STR_Z(ioReadLine(read), "12", "read line");
 
         // Read what was left in the line buffer
-        TEST_RESULT_INT(ioRead(read, buffer), 0, "read buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 0, "read buffer");
         bufUsedSet(buffer, 2);
-        TEST_RESULT_INT(ioRead(read, buffer), 1, "read buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AAB", "    check buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 1, "read buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AAB", "    check buffer");
         bufUsedSet(buffer, 0);
 
         // Now do a full buffer read from the input
-        TEST_RESULT_INT(ioRead(read, buffer), 3, "read buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "DDD", "    check buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 3, "read buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "DDD", "    check buffer");
 
         // Read line doesn't work without a linefeed
         TEST_ERROR(ioReadLine(read), FileReadError, "unexpected eof while reading line");
 
         // But those bytes can be picked up by a buffer read
         buffer = bufNew(2);
-        TEST_RESULT_INT(ioRead(read, buffer), 2, "read buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "EF", "    check buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 2, "read buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "EF", "    check buffer");
 
         buffer = bufNew(1);
-        TEST_RESULT_INT(ioRead(read, buffer), 1, "read buffer");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "F", "    check buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 1, "read buffer");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "F", "    check buffer");
 
         // Nothing left to read
         TEST_ERROR(ioReadLine(read), FileReadError, "unexpected eof while reading line");
-        TEST_RESULT_INT(ioRead(read, buffer), 0, "read buffer");
+        TEST_RESULT_UINT(ioRead(read, buffer), 0, "read buffer");
 
         // Error if buffer is full and there is no linefeed
         ioBufferSizeSet(10);
@@ -434,7 +442,7 @@ testRun(void)
         // Read line without eof
         read = ioBufferReadNew(BUFSTRDEF("1234"));
         ioReadOpen(read);
-        TEST_RESULT_STR(strPtr(ioReadLineParam(read, true)), "1234", "read line without eof");
+        TEST_RESULT_STR_Z(ioReadLineParam(read, true), "1234", "read line without eof");
 
         // Read IO into a buffer
         // -------------------------------------------------------------------------------------------------------------------------
@@ -443,7 +451,7 @@ testRun(void)
         bufferRead = ioBufferReadNew(BUFSTRDEF("a test string"));
         ioReadOpen(bufferRead);
 
-        TEST_RESULT_STR(strPtr(strNewBuf(ioReadBuf(bufferRead))), "a test string", "read into buffer");
+        TEST_RESULT_STR_Z(strNewBuf(ioReadBuf(bufferRead)), "a test string", "read into buffer");
 
         // Drain read IO
         // -------------------------------------------------------------------------------------------------------------------------
@@ -499,15 +507,15 @@ testRun(void)
         TEST_RESULT_VOID(ioWriteLine(bufferWrite, BUFSTRDEF("AB")), "    write line");
         TEST_RESULT_VOID(ioWrite(bufferWrite, bufNew(0)), "    write 0 bytes");
         TEST_RESULT_VOID(ioWrite(bufferWrite, NULL), "    write 0 bytes");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AABB\n\n", "    check write");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AABB\n\n", "    check write");
 
         TEST_RESULT_VOID(ioWriteStr(bufferWrite, STRDEF("Z")), "    write string");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AABB\n\n", "    no change because output buffer is not full");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AABB\n\n", "    no change because output buffer is not full");
         TEST_RESULT_VOID(ioWriteStr(bufferWrite, STRDEF("12345")), "    write bytes");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AABB\n\nZZ1122334455", "    check write");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AABB\n\nZZ1122334455", "    check write");
 
         TEST_RESULT_VOID(ioWriteClose(bufferWrite), " close buffer write object");
-        TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "AABB\n\nZZ1122334455XXXY", "    check write after close");
+        TEST_RESULT_STR_Z(strNewBuf(buffer), "AABB\n\nZZ1122334455XXXY", "    check write after close");
 
         TEST_RESULT_PTR(ioWriteFilterGroup(bufferWrite), filterGroup, "    check filter group");
         TEST_RESULT_UINT(
@@ -561,7 +569,7 @@ testRun(void)
                 TEST_RESULT_PTR(ioReadDriver(read), read->driver, "check driver");
 
                 // Read a string
-                TEST_RESULT_STR(strPtr(ioReadLine(read)), "test string 1", "read test string");
+                TEST_RESULT_STR_Z(ioReadLine(read), "test string 1", "read test string");
 
                 // Only part of the buffer is written before timeout
                 Buffer *buffer = bufNew(16);
@@ -576,7 +584,7 @@ testRun(void)
                 TEST_RESULT_UINT(ioRead(read, buffer), 12, "read buffer");
                 bufLimitClear(buffer);
                 TEST_RESULT_UINT(ioRead(read, buffer), 4, "read buffer");
-                TEST_RESULT_STR(strPtr(strNewBuf(buffer)), "1234567812345678", "check buffer");
+                TEST_RESULT_STR_Z(strNewBuf(buffer), "1234567812345678", "check buffer");
 
                 // Check EOF
                 buffer = bufNew(16);
