@@ -3,18 +3,11 @@ Test Configuration Load
 ***********************************************************************************************************************************/
 #include "common/io/io.h"
 #include "common/log.h"
+#include "protocol/helper.h"
 #include "version.h"
 
 #include "common/harnessConfig.h"
 
-/***********************************************************************************************************************************
-Expose log internal data for unit testing/debugging
-***********************************************************************************************************************************/
-extern LogLevel logLevelStdOut;
-extern LogLevel logLevelStdErr;
-extern LogLevel logLevelFile;
-extern bool logTimestamp;
-
 /***********************************************************************************************************************************
 Test run
 ***********************************************************************************************************************************/
@@ -34,36 +27,6 @@ testRun(void)
         TEST_RESULT_INT(logLevelStdErr, logLevelOff, "stderr logging is off");
         TEST_RESULT_INT(logLevelFile, logLevelOff, "file logging is off");
         TEST_RESULT_BOOL(logTimestamp, true, "timestamp logging is on");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        cfgInit();
-        cfgCommandSet(cfgCmdLocal);
-
-        cfgOptionValidSet(cfgOptLogLevelConsole, true);
-        cfgOptionSet(cfgOptLogLevelConsole, cfgSourceParam, varNewStrZ("info"));
-        cfgOptionValidSet(cfgOptLogLevelStderr, true);
-        cfgOptionSet(cfgOptLogLevelStderr, cfgSourceParam, varNewStrZ("error"));
-        cfgOptionValidSet(cfgOptLogLevelFile, true);
-        cfgOptionSet(cfgOptLogLevelFile, cfgSourceParam, varNewStrZ("debug"));
-        cfgOptionValidSet(cfgOptLogTimestamp, true);
-        cfgOptionSet(cfgOptLogTimestamp, cfgSourceParam, varNewBool(false));
-
-        TEST_RESULT_VOID(cfgLoadLogSetting(), "load log settings no defaults");
-        TEST_RESULT_INT(logLevelStdOut, logLevelInfo, "console logging is info");
-        TEST_RESULT_INT(logLevelStdErr, logLevelError, "stderr logging is error");
-        TEST_RESULT_INT(logLevelFile, logLevelDebug, "file logging is debugging");
-        TEST_RESULT_BOOL(logTimestamp, false, "timestamp logging is off");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        cfgInit();
-        cfgCommandSet(cfgCmdLocal);
-
-        cfgOptionValidSet(cfgOptLogLevelStderr, true);
-        cfgOptionSet(cfgOptLogLevelStderr, cfgSourceParam, varNewStrZ("info"));
-
-        TEST_RESULT_VOID(cfgLoadLogSetting(), "load log settings reset stderr");
-
-        TEST_RESULT_INT(logLevelStdErr, logLevelError, "stderr logging is error");
     }
 
     // *****************************************************************************************************************************
@@ -73,7 +36,7 @@ testRun(void)
         String *exeOther = strNew("/other/path/to/pgbackrest");
 
         cfgInit();
-        cfgCommandSet(cfgCmdBackup);
+        cfgCommandSet(cfgCmdBackup, cfgCmdRoleDefault);
         cfgExeSet(exe);
 
         cfgOptionValidSet(cfgOptRepoHost, true);
@@ -84,12 +47,12 @@ testRun(void)
         cfgOptionSet(cfgOptRepoHost, cfgSourceParam, varNewStrZ("repo-host"));
 
         TEST_RESULT_VOID(cfgLoadUpdateOption(), "repo remote command is updated");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoHostCmd)), strPtr(exe), "    check repo1-host-cmd");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptRepoHostCmd), exe, "    check repo1-host-cmd");
 
         cfgOptionSet(cfgOptRepoHostCmd, cfgSourceParam, varNewStr(exeOther));
 
         TEST_RESULT_VOID(cfgLoadUpdateOption(), "repo remote command was already set");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoHostCmd)), strPtr(exeOther), "    check repo1-host-cmd");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptRepoHostCmd), exeOther, "    check repo1-host-cmd");
 
         cfgOptionSet(cfgOptRepoHost, cfgSourceParam, NULL);
 
@@ -106,11 +69,10 @@ testRun(void)
         cfgOptionSet(cfgOptPgHost + cfgOptionIndexTotal(cfgOptPgHost) - 1, cfgSourceParam, varNewStrZ("pgX-host"));
 
         TEST_RESULT_VOID(cfgLoadUpdateOption(), "pg remote command is updated");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgHostCmd)), strPtr(exe), "    check pg1-host-cmd");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgHostCmd + 1)), strPtr(exeOther), "    check pg2-host-cmd is already set");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgHostCmd + 2)), NULL, "    check pg3-host-cmd is not set");
-        TEST_RESULT_STR(
-            strPtr(cfgOptionStr(cfgOptPgHostCmd + cfgOptionIndexTotal(cfgOptPgHost) - 1)), strPtr(exe), "    check pgX-host-cmd");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptPgHostCmd), exe, "    check pg1-host-cmd");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptPgHostCmd + 1), exeOther, "    check pg2-host-cmd is already set");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptPgHostCmd + 2), NULL, "    check pg3-host-cmd is not set");
+        TEST_RESULT_STR(cfgOptionStr(cfgOptPgHostCmd + cfgOptionIndexTotal(cfgOptPgHost) - 1), exe, "    check pgX-host-cmd");
 
         // -------------------------------------------------------------------------------------------------------------------------
         cfgInit();
@@ -148,7 +110,7 @@ testRun(void)
 
         // -------------------------------------------------------------------------------------------------------------------------
         cfgInit();
-        cfgCommandSet(cfgCmdBackup);
+        cfgCommandSet(cfgCmdBackup, cfgCmdRoleDefault);
         cfgExeSet(exe);
 
         cfgOptionValidSet(cfgOptPgHost, true);
@@ -281,7 +243,7 @@ testRun(void)
         strLstAdd(argList, strNew("--repo1-path=/repo"));
 
         TEST_RESULT_VOID(harnessCfgLoad(cfgCmdArchiveGet, argList), "invalid bucket with no verification");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoS3Bucket)), "bogus.bucket", "    check bucket value");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptRepoS3Bucket), "bogus.bucket", "    check bucket value");
 
         // Valid bucket name
         argList = strLstNew();
@@ -293,10 +255,53 @@ testRun(void)
         strLstAdd(argList, strNew("--repo1-path=/repo"));
 
         TEST_RESULT_VOID(harnessCfgLoad(cfgCmdArchiveGet, argList), "valid bucket name");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoS3Bucket)), "cool-bucket", "    check bucket value");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptRepoS3Bucket), "cool-bucket", "    check bucket value");
+        TEST_RESULT_BOOL(cfgOptionValid(cfgOptCompress), false, "    compress is not valid");
 
         unsetenv("PGBACKREST_REPO1_S3_KEY");
         unsetenv("PGBACKREST_REPO1_S3_KEY_SECRET");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compress-type=none when compress=n");
+
+        argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=db");
+        strLstAddZ(argList, "--no-" CFGOPT_COMPRESS);
+
+        TEST_RESULT_VOID(harnessCfgLoad(cfgCmdArchivePush, argList), "load config");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptCompressType), "none", "    compress-type=none");
+        TEST_RESULT_INT(cfgOptionInt(cfgOptCompressLevel), 0, "    compress-level=0");
+        TEST_RESULT_BOOL(cfgOptionValid(cfgOptCompress), false, "    compress is not valid");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compress-type=gz when compress=y");
+
+        argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=db");
+        strLstAddZ(argList, "--" CFGOPT_COMPRESS);
+        strLstAddZ(argList, "--" CFGOPT_COMPRESS_LEVEL "=9");
+
+        TEST_RESULT_VOID(harnessCfgLoad(cfgCmdArchivePush, argList), "load config");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptCompressType), "gz", "    compress-type=gz");
+        TEST_RESULT_INT(cfgOptionInt(cfgOptCompressLevel), 9, "    compress-level=9");
+        TEST_RESULT_BOOL(cfgOptionValid(cfgOptCompress), false, "    compress is not valid");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("warn when compress-type and compress both set");
+
+        argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=db");
+        strLstAddZ(argList, "--no-" CFGOPT_COMPRESS);
+        strLstAddZ(argList, "--" CFGOPT_COMPRESS_TYPE "=gz");
+
+        TEST_RESULT_VOID(harnessCfgLoad(cfgCmdArchivePush, argList), "load config");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptCompressType), "gz", "    compress-type=gz");
+        TEST_RESULT_INT(cfgOptionInt(cfgOptCompressLevel), 6, "    compress-level=6");
+        TEST_RESULT_BOOL(cfgOptionValid(cfgOptCompress), false, "    compress is not valid");
+
+        harnessLogResult(
+            "P00   WARN: 'compress' and 'compress-type' options should not both be set\n"
+            "            HINT: 'compress-type' is preferred and 'compress' is deprecated.");
     }
 
     // *****************************************************************************************************************************
@@ -315,15 +320,37 @@ testRun(void)
 
         // On the error case is tested here, success is tested in cfgLoad()
         TEST_RESULT_VOID(cfgLoadLogFile(), "attempt to open bogus log file");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptLogLevelFile)), "off", "log-level-file should now be off");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptLogLevelFile), "off", "log-level-file should now be off");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("cfgLoad()"))
     {
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("dry-run valid, --no-dry-run");
+
+        StringList *argList = strLstNew();
+        strLstAddZ(argList, PROJECT_BIN);
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=db");
+        strLstAdd(argList, strNewFmt("--" CFGOPT_LOCK_PATH "=%s/lock", testDataPath()));
+        strLstAddZ(argList, CFGCMD_EXPIRE);
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "load config");
+        TEST_RESULT_VOID(storageRepoWrite(), "  check writable storage");
+        lockRelease(true);
+
+        TEST_TITLE("dry-run valid, dry-run");
+
+        strLstAddZ(argList, "--" CFGOPT_DRY_RUN);
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "load config");
+        TEST_ERROR(
+            storageRepoWrite(), AssertError, "unable to get writable storage in dry-run mode or before dry-run is initialized");
+        lockRelease(true);
+
         // Command does not have umask
         // -------------------------------------------------------------------------------------------------------------------------
-        StringList *argList = strLstNew();
+        argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("info"));
 
@@ -373,7 +400,7 @@ testRun(void)
 
         ioBufferSizeSet(333);
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command");
-        TEST_RESULT_SIZE(ioBufferSize(), 333, "buffer size not updated by help command");
+        TEST_RESULT_UINT(ioBufferSize(), 333, "buffer size not updated by help command");
 
         // Help command for backup
         // -------------------------------------------------------------------------------------------------------------------------
@@ -387,7 +414,7 @@ testRun(void)
         strLstAdd(argList, strNew("--repo1-retention-full=2"));
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "help command for backup");
-        TEST_RESULT_SIZE(ioBufferSize(), 4 * 1024 * 1024, "buffer size set to option default");
+        TEST_RESULT_UINT(ioBufferSize(), 4 * 1024 * 1024, "buffer size set to option default");
 
         // Command takes lock and opens log file
         // -------------------------------------------------------------------------------------------------------------------------
@@ -408,18 +435,20 @@ testRun(void)
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "lock and open log file");
         TEST_RESULT_INT(lstat(strPtr(strNewFmt("%s/db-backup.log", testPath())), &statLog), 0, "   check log file exists");
 
+        lockRelease(true);
+
         // Local command opens log file with special filename
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--command=backup"));
         strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to");
         strLstAdd(argList, strNew("--process=1"));
         strLstAdd(argList, strNew("--host-id=1"));
-        strLstAdd(argList, strNew("--type=backup"));
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
         strLstAdd(argList, strNew("--log-level-file=warn"));
-        strLstAdd(argList, strNew("local"));
+        strLstAddZ(argList, CFGCMD_BACKUP ":" CONFIG_COMMAND_ROLE_LOCAL);
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
         TEST_RESULT_INT(
@@ -429,16 +458,68 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
-        strLstAdd(argList, strNew("--command=backup"));
         strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
-        strLstAdd(argList, strNew("--type=backup"));
-        strLstAdd(argList, strNew("--log-level-file=warn"));
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
+        strLstAddZ(argList, "--" CFGOPT_LOG_LEVEL_FILE "=info");
+        strLstAddZ(argList, "--" CFGOPT_LOG_SUBPROCESS);
         strLstAdd(argList, strNew("--process=0"));
-        strLstAdd(argList, strNew("remote"));
+        strLstAddZ(argList, CFGCMD_INFO ":" CONFIG_COMMAND_ROLE_REMOTE);
 
         TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
         TEST_RESULT_INT(
-            lstat(strPtr(strNewFmt("%s/all-backup-remote-000.log", testPath())), &statLog), 0, "   check log file exists");
+            lstat(strPtr(strNewFmt("%s/all-info-remote-000.log", testPath())), &statLog), 0, "   check log file exists");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("remote command without archive-async option");
+
+        argList = strLstNew();
+        strLstAdd(argList, strNew("pgbackrest"));
+        strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
+        strLstAddZ(argList, "--" CFGOPT_LOG_LEVEL_FILE "=info");
+        strLstAddZ(argList, "--" CFGOPT_LOG_SUBPROCESS);
+        strLstAdd(argList, strNew("--process=1"));
+        strLstAddZ(argList, CFGCMD_ARCHIVE_GET ":" CONFIG_COMMAND_ROLE_REMOTE);
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
+        TEST_RESULT_INT(
+            lstat(strPtr(strNewFmt("%s/test-archive-get-remote-001.log", testPath())), &statLog), 0, "   check log file exists");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("local command with archive-async option");
+
+        argList = strLstNew();
+        strLstAdd(argList, strNew("pgbackrest"));
+        strLstAdd(argList, strNewFmt("--log-path=%s", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
+        strLstAddZ(argList, "--" CFGOPT_LOG_LEVEL_FILE "=info");
+        strLstAddZ(argList, "--" CFGOPT_LOG_SUBPROCESS);
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        strLstAdd(argList, strNew("--process=1"));
+        strLstAddZ(argList, CFGCMD_ARCHIVE_PUSH ":" CONFIG_COMMAND_ROLE_LOCAL);
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
+        TEST_RESULT_INT(
+            lstat(strPtr(strNewFmt("%s/test-archive-push-async-local-001.log", testPath())), &statLog), 0,
+            "   check log file exists");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("archive-get command with async role");
+
+        argList = strLstNew();
+        strLstAddZ(argList, PROJECT_BIN);
+        strLstAdd(argList, strNewFmt("--" CFGOPT_LOG_PATH "=%s", testPath()));
+        strLstAdd(argList, strNewFmt("--lock-path=%s/lock", testDataPath()));
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test");
+        strLstAddZ(argList, CFGCMD_ARCHIVE_GET ":" CONFIG_COMMAND_ROLE_ASYNC);
+
+        TEST_RESULT_VOID(cfgLoad(strLstSize(argList), strLstPtr(argList)), "open log file");
+        TEST_RESULT_INT(
+            lstat(strPtr(strNewFmt("%s/test-archive-get-async.log", testPath())), &statLog), 0, "   check log file exists");
+
+        lockRelease(true);
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
