@@ -1,6 +1,7 @@
 /***********************************************************************************************************************************
 Test Configuration Parse
 ***********************************************************************************************************************************/
+#include "protocol/helper.h"
 #include "storage/storage.intern.h"
 
 #define TEST_BACKREST_EXE                                           "pgbackrest"
@@ -11,12 +12,6 @@ Test Configuration Parse
 #define TEST_COMMAND_RESTORE                                        "restore"
 #define TEST_COMMAND_VERSION                                        "version"
 
-/***********************************************************************************************************************************
-Expose log internal data for unit testing/debugging
-***********************************************************************************************************************************/
-extern LogLevel logLevelStdOut;
-extern LogLevel logLevelStdErr;
-
 /***********************************************************************************************************************************
 Option find test -- this is done a lot in the deprecated tests
 ***********************************************************************************************************************************/
@@ -50,8 +45,8 @@ testRun(void)
 
         // Check old config file constants
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(PGBACKREST_CONFIG_ORIG_PATH_FILE, "/etc/pgbackrest.conf", "check old config path");
-        TEST_RESULT_STR(strPtr(PGBACKREST_CONFIG_ORIG_PATH_FILE_STR), "/etc/pgbackrest.conf", "check old config path str");
+        TEST_RESULT_Z(PGBACKREST_CONFIG_ORIG_PATH_FILE, "/etc/pgbackrest.conf", "check old config path");
+        TEST_RESULT_STR_Z(PGBACKREST_CONFIG_ORIG_PATH_FILE_STR, "/etc/pgbackrest.conf", "check old config path str");
 
         // Confirm same behavior with multiple config include files
         //--------------------------------------------------------------------------------------------------------------------------
@@ -78,8 +73,8 @@ testRun(void)
                 "[global:backup]\n"
                 "repo1-hardlink=y\n"
                 "bogus=bogus\n"
-                "no-compress=y\n"
-                "reset-compress=y\n"
+                "no-delta=y\n"
+                "reset-delta=y\n"
                 "archive-copy=y\n"
                 "online=y\n"
                 "pg1-path=/not/path/to/db\n"
@@ -90,7 +85,7 @@ testRun(void)
             storageNewWriteP(storageLocalWrite(), strNewFmt("%s/db-backup.conf", strPtr(configIncludePath))),
             BUFSTRDEF(
                 "[db:backup]\n"
-                "compress=n\n"
+                "delta=n\n"
                 "recovery-option=a=b\n"));
 
         storagePut(
@@ -108,16 +103,16 @@ testRun(void)
                 strNew(
                     "P00   WARN: configuration file contains option 'recovery-option' invalid for section 'db:backup'\n"
                     "P00   WARN: configuration file contains invalid option 'bogus'\n"
-                    "P00   WARN: configuration file contains negate option 'no-compress'\n"
-                    "P00   WARN: configuration file contains reset option 'reset-compress'\n"
+                    "P00   WARN: configuration file contains negate option 'no-delta'\n"
+                    "P00   WARN: configuration file contains reset option 'reset-delta'\n"
                     "P00   WARN: configuration file contains command-line only option 'online'\n"
                     "P00   WARN: configuration file contains stanza-only option 'pg1-path' in global section 'global:backup'")));
 
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptPgHost), false, "    pg1-host is not set (command line reset override)");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgPath)), "/path/to/db", "    pg1-path is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptPgPath), "/path/to/db", "    pg1-path is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptPgPath), cfgSourceConfig, "    pg1-path is source config");
-        TEST_RESULT_BOOL(cfgOptionBool(cfgOptCompress), false, "    compress not is set");
-        TEST_RESULT_INT(cfgOptionSource(cfgOptCompress), cfgSourceConfig, "    compress is source config");
+        TEST_RESULT_BOOL(cfgOptionBool(cfgOptDelta), false, "    delta not is set");
+        TEST_RESULT_INT(cfgOptionSource(cfgOptDelta), cfgSourceConfig, "    delta is source config");
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptArchiveCheck), false, "    archive-check is not set");
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptArchiveCopy), false, "    archive-copy is not set");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptRepoHardlink), true, "    repo-hardlink is set");
@@ -126,7 +121,7 @@ testRun(void)
         TEST_RESULT_INT(cfgOptionSource(cfgOptCompressLevel), cfgSourceConfig, "    compress-level is source config");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptBackupStandby), false, "    backup-standby not is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptBackupStandby), cfgSourceDefault, "    backup-standby is source default");
-        TEST_RESULT_BOOL(cfgOptionInt64(cfgOptBufferSize), 65536, "    buffer-size is set");
+        TEST_RESULT_INT(cfgOptionInt64(cfgOptBufferSize), 65536, "    buffer-size is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptBufferSize), cfgSourceConfig, "    backup-standby is source config");
 
         // Rename conf files - ensure read of conf extension only is attempted
@@ -138,14 +133,13 @@ testRun(void)
 
         // Set up defaults
         String *backupCmdDefConfigValue = strNew(cfgDefOptionDefault(
-            cfgCommandDefIdFromId(cfgCommandId(TEST_COMMAND_BACKUP)), cfgOptionDefIdFromId(cfgOptConfig)));
+            cfgCommandDefIdFromId(cfgCommandId(TEST_COMMAND_BACKUP, true)), cfgOptionDefIdFromId(cfgOptConfig)));
         String *backupCmdDefConfigInclPathValue = strNew(cfgDefOptionDefault(
-                cfgCommandDefIdFromId(cfgCommandId(TEST_COMMAND_BACKUP)), cfgOptionDefIdFromId(cfgOptConfigIncludePath)));
+                cfgCommandDefIdFromId(cfgCommandId(TEST_COMMAND_BACKUP, true)), cfgOptionDefIdFromId(cfgOptConfigIncludePath)));
         String *oldConfigDefault = strNewFmt("%s%s", testPath(), PGBACKREST_CONFIG_ORIG_PATH_FILE);
 
         // Create the option structure and initialize with 0
-        ParseOption parseOptionList[CFG_OPTION_TOTAL];
-        memset(&parseOptionList, 0, sizeof(parseOptionList));
+        ParseOption parseOptionList[CFG_OPTION_TOTAL] = {{.found = false}};
 
         StringList *value = strLstNew();
         strLstAdd(value, configFile);
@@ -163,8 +157,8 @@ testRun(void)
 
         TEST_RESULT_VOID(cfgFileLoadPart(NULL, NULL), "check null part");
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n"
@@ -212,10 +206,9 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].found = false;
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceDefault;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
-            NULL,
-            "config default, config-include-path default but nothing to read");
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
+            NULL, "config default, config-include-path default but nothing to read");
 
         // Config not passed as parameter - config does not exist. config-include-path passed as parameter - only include read
         //--------------------------------------------------------------------------------------------------------------------------
@@ -228,8 +221,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[db]\n"
             "pg1-host=db\n"
             "pg1-path=/path/to/db\n"
@@ -253,8 +246,8 @@ testRun(void)
 
         // Pass actual location of config files as "default" - not setting valueList above, so these are the only possible values
         // to choose.
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, configFile,  configIncludePath,
-            oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, configFile,  configIncludePath, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n"
@@ -277,8 +270,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global:backup]\n"
             "buffer-size=65536\n"
             "\n"
@@ -300,8 +293,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[db]\n"
             "pg1-host=db\n"
             "pg1-path=/path/to/db\n"
@@ -316,10 +309,9 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].found = false;
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceDefault;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            configIncludePath, oldConfigDefault)),
-            NULL,
-            "--no-config, config-include-path default, nothing read");
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, configIncludePath, oldConfigDefault),
+            NULL, "--no-config, config-include-path default, nothing read");
 
         // config passed and config-include-path default exists with files - only config read
         //--------------------------------------------------------------------------------------------------------------------------
@@ -333,8 +325,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].found = false;
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceDefault;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            configIncludePath, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, configIncludePath, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n",
@@ -351,8 +343,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, configFile,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, configFile, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n"
@@ -371,8 +363,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceDefault;
 
         // File exists in old default config location but not in current default.
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            configIncludePath, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, configIncludePath, oldConfigDefault),
             "[global:backup]\n"
             "buffer-size=65536\n"
             "\n"
@@ -392,8 +384,8 @@ testRun(void)
 
         // Override default paths for config and config-include-path - but no pgbackrest.conf file in override path only in old
         // default so ignored
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[db]\n"
             "pg1-host=db\n"
             "pg1-path=/path/to/db\n"
@@ -411,8 +403,8 @@ testRun(void)
 
         // Passing --config and --config-path - default config-include-path overwritten and config is required and is loaded and
         // config-include-path files will attempt to be loaded but not required
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n"
@@ -430,8 +422,8 @@ testRun(void)
 
         // Passing --config and bogus --config-path - default config-include-path overwritten, config is required and is loaded and
         // config-include-path files will attempt to be loaded but doesn't exist - no error since not required
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n",
@@ -456,8 +448,8 @@ testRun(void)
         parseOptionList[cfgOptConfigPath].valueList = value;
 
         // Override default paths for config and config-include-path with --config-path
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n"
@@ -486,8 +478,8 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, configFile,
-            backupCmdDefConfigInclPathValue, oldConfigDefault)),
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, configFile, backupCmdDefConfigInclPathValue, oldConfigDefault),
             "[global]\n"
             "compress-level=3\n"
             "spool-path=/path/to/spool\n",
@@ -507,10 +499,9 @@ testRun(void)
         parseOptionList[cfgOptConfigIncludePath].source = cfgSourceParam;
         parseOptionList[cfgOptConfigIncludePath].valueList = value;
 
-        TEST_RESULT_STR(strPtr(cfgFileLoad(parseOptionList, backupCmdDefConfigValue,
-            backupCmdDefConfigInclPathValue, backupCmdDefConfigValue)),
-            NULL,
-            "config default does not exist, config-include-path passed but only empty conf file - nothing read");
+        TEST_RESULT_STR_Z(
+            cfgFileLoad(parseOptionList, backupCmdDefConfigValue, backupCmdDefConfigInclPathValue, backupCmdDefConfigValue),
+            NULL, "config default does not exist, config-include-path passed but only empty conf file - nothing read");
     }
 
     // *****************************************************************************************************************************
@@ -532,68 +523,68 @@ testRun(void)
         strCat(value, "10");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10, "valueDbl no character identifier - straight to bytes");
-        TEST_RESULT_STR(strPtr(value), "10", "value no character identifier - straight to bytes");
+        TEST_RESULT_STR_Z(value, "10", "value no character identifier - straight to bytes");
 
         strCat(value, "B");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10, "valueDbl B to bytes");
-        TEST_RESULT_STR(strPtr(value), "10", "value B to bytes");
+        TEST_RESULT_STR_Z(value, "10", "value B to bytes");
 
         strCat(value, "Kb");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10240, "valueDbl KB to bytes");
-        TEST_RESULT_STR(strPtr(value), "10240", "value KB to bytes");
+        TEST_RESULT_STR_Z(value, "10240", "value KB to bytes");
 
         strTrunc(value, strChr(value, '2'));
         strCat(value, "k");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10240, "valueDbl k to bytes");
-        TEST_RESULT_STR(strPtr(value), "10240", "value k to bytes");
+        TEST_RESULT_STR_Z(value, "10240", "value k to bytes");
 
         strCat(value, "pB");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 11529215046068469760U, "valueDbl Pb to bytes");
-        TEST_RESULT_STR(strPtr(value), "11529215046068469760", "value Pb to bytes");
+        TEST_RESULT_STR_Z(value, "11529215046068469760", "value Pb to bytes");
 
         strTrunc(value, strChr(value, '5'));
         strCat(value, "GB");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 11811160064U, "valueDbl GB to bytes");
-        TEST_RESULT_STR(strPtr(value), "11811160064", "value GB to bytes");
+        TEST_RESULT_STR_Z(value, "11811160064", "value GB to bytes");
 
         strTrunc(value, strChr(value, '8'));
         strCat(value, "g");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 11811160064U, "valueDbl g to bytes");
-        TEST_RESULT_STR(strPtr(value), "11811160064", "value g to bytes");
+        TEST_RESULT_STR_Z(value, "11811160064", "value g to bytes");
 
         strTrunc(value, strChr(value, '8'));
         strCat(value, "T");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 12094627905536U, "valueDbl T to bytes");
-        TEST_RESULT_STR(strPtr(value), "12094627905536", "value T to bytes");
+        TEST_RESULT_STR_Z(value, "12094627905536", "value T to bytes");
 
         strTrunc(value, strChr(value, '0'));
         strCat(value, "tb");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 13194139533312U, "valueDbl tb to bytes");
-        TEST_RESULT_STR(strPtr(value), "13194139533312", "value tb to bytes");
+        TEST_RESULT_STR_Z(value, "13194139533312", "value tb to bytes");
 
         strTrunc(value, strChr(value, '3'));
         strCat(value, "0m");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10485760, "valueDbl m to bytes");
-        TEST_RESULT_STR(strPtr(value), "10485760", "value m to bytes");
+        TEST_RESULT_STR_Z(value, "10485760", "value m to bytes");
 
         strCat(value, "mb");
         convertToByte(&value, &valueDbl);
         TEST_RESULT_DOUBLE(valueDbl, 10995116277760U, "valueDbl mb to bytes");
-        TEST_RESULT_STR(strPtr(value), "10995116277760", "value mb to bytes");
+        TEST_RESULT_STR_Z(value, "10995116277760", "value mb to bytes");
 
         strTrunc(value, strChr(value, '0'));
         strCat(value, "99999999999999999999p");
         convertToByte(&value, &valueDbl);
-        TEST_RESULT_STR(strPtr(value), "225179981368524800000000000000000000", "value really large  to bytes");
+        TEST_RESULT_STR_Z(value, "225179981368524800000000000000000000", "value really large  to bytes");
     }
 
     // *****************************************************************************************************************************
@@ -612,6 +603,13 @@ testRun(void)
         strLstAdd(argList, strNew(BOGUS_STR));
         TEST_ERROR(configParse(strLstSize(argList), strLstPtr(argList), false), CommandInvalidError, "invalid command 'BOGUS'");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
+        strLstAdd(argList, strNew(TEST_BACKREST_EXE));
+        strLstAdd(argList, strNew(BOGUS_STR ":" BOGUS_STR));
+        TEST_ERROR(
+            configParse(strLstSize(argList), strLstPtr(argList), false), CommandInvalidError, "invalid command 'BOGUS:BOGUS'");
+
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew(TEST_BACKREST_EXE));
@@ -681,29 +679,29 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew(TEST_BACKREST_EXE));
-        strLstAdd(argList, strNew("--no-compress"));
-        strLstAdd(argList, strNew("--reset-compress"));
+        strLstAdd(argList, strNew("--no-delta"));
+        strLstAdd(argList, strNew("--reset-delta"));
         TEST_ERROR(
             configParse(strLstSize(argList), strLstPtr(argList), false), OptionInvalidError,
-            "option 'compress' cannot be negated and reset");
+            "option 'delta' cannot be negated and reset");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew(TEST_BACKREST_EXE));
-        strLstAdd(argList, strNew("--reset-compress"));
-        strLstAdd(argList, strNew("--no-compress"));
+        strLstAdd(argList, strNew("--reset-delta"));
+        strLstAdd(argList, strNew("--no-delta"));
         TEST_ERROR(
             configParse(strLstSize(argList), strLstPtr(argList), false), OptionInvalidError,
-            "option 'compress' cannot be negated and reset");
+            "option 'delta' cannot be negated and reset");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
         strLstAdd(argList, strNew(TEST_BACKREST_EXE));
-        strLstAdd(argList, strNew("--compress"));
-        strLstAdd(argList, strNew("--compress"));
+        strLstAdd(argList, strNew("--delta"));
+        strLstAdd(argList, strNew("--delta"));
         TEST_ERROR(
             configParse(strLstSize(argList), strLstPtr(argList), false), OptionInvalidError,
-            "option 'compress' cannot be set multiple times");
+            "option 'delta' cannot be set multiple times");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -781,12 +779,12 @@ testRun(void)
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
         strLstAdd(argList, strNew("--host-id=1"));
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to");
         strLstAdd(argList, strNew("--process=1"));
-        strLstAdd(argList, strNew("--command=backup"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--type=backup"));
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
         strLstAdd(argList, strNew("--log-level-stderr=info"));
-        strLstAdd(argList, strNew("local"));
+        strLstAddZ(argList, CFGCMD_BACKUP ":" CONFIG_COMMAND_ROLE_LOCAL);
 
         logLevelStdOut = logLevelError;
         logLevelStdErr = logLevelError;
@@ -796,12 +794,12 @@ testRun(void)
 
         argList = strLstNew();
         strLstAdd(argList, strNew("pgbackrest"));
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/path/to");
         strLstAdd(argList, strNew("--process=1"));
-        strLstAdd(argList, strNew("--command=backup"));
         strLstAdd(argList, strNew("--stanza=db"));
-        strLstAdd(argList, strNew("--type=backup"));
+        strLstAddZ(argList, "--" CFGOPT_REMOTE_TYPE "=" PROTOCOL_REMOTE_TYPE_REPO);
         strLstAdd(argList, strNew("--log-level-stderr=info"));
-        strLstAdd(argList, strNew("remote"));
+        strLstAddZ(argList, CFGCMD_BACKUP ":" CONFIG_COMMAND_ROLE_REMOTE);
 
         logLevelStdOut = logLevelError;
         logLevelStdErr = logLevelError;
@@ -1013,11 +1011,11 @@ testRun(void)
             storageNewWriteP(storageLocalWrite(), configFile),
             BUFSTRDEF(
                 "[global]\n"
-                "compress=bogus\n"));
+                "delta=bogus\n"));
 
         TEST_ERROR(configParse(
             strLstSize(argList), strLstPtr(argList), false), OptionInvalidValueError,
-            "boolean option 'compress' must be 'y' or 'n'");
+            "boolean option 'delta' must be 'y' or 'n'");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -1030,11 +1028,11 @@ testRun(void)
             storageNewWriteP(storageLocalWrite(), configFile),
             BUFSTRDEF(
                 "[global]\n"
-                "compress=\n"));
+                "delta=\n"));
 
         TEST_ERROR(configParse(
             strLstSize(argList), strLstPtr(argList), false), OptionInvalidValueError,
-            "section 'global', key 'compress' must have a value");
+            "section 'global', key 'delta' must have a value");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -1138,8 +1136,8 @@ testRun(void)
         strLstAdd(argList, strNew("000000010000000200000003"));
         strLstAdd(argList, strNew("/path/to/wal/RECOVERYWAL"));
         TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "command arguments");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(cfgCommandParam(), "|")), "000000010000000200000003|/path/to/wal/RECOVERYWAL",
+        TEST_RESULT_STR_Z(
+            strLstJoin(cfgCommandParam(), "|"), "000000010000000200000003|/path/to/wal/RECOVERYWAL",
             "    check command arguments");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -1159,22 +1157,20 @@ testRun(void)
         TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), TEST_COMMAND_BACKUP " command");
         TEST_RESULT_INT(cfgCommand(), cfgCmdBackup, "    command is " TEST_COMMAND_BACKUP);
 
-        TEST_RESULT_STR(strPtr(cfgExe()), TEST_BACKREST_EXE, "    exe is set");
+        TEST_RESULT_STR_Z(cfgExe(), TEST_BACKREST_EXE, "    exe is set");
 
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptConfig), false, "    config is not set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptConfig), cfgSourceParam, "    config is source param");
         TEST_RESULT_BOOL(cfgOptionNegate(cfgOptConfig), true, "    config is negated");
         TEST_RESULT_INT(cfgOptionSource(cfgOptStanza), cfgSourceParam, "    stanza is source param");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptStanza)), "db", "    stanza is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptStanza), "db", "    stanza is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptStanza), cfgSourceParam, "    stanza is source param");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgPath)), "/path/to/db", "    pg1-path is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptPgPath), "/path/to/db", "    pg1-path is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptPgPath), cfgSourceParam, "    pg1-path is source param");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoS3KeySecret)), "xxx", "    repo1-s3-secret is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptRepoS3KeySecret), "xxx", "    repo1-s3-secret is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptRepoS3KeySecret), cfgSourceConfig, "    repo1-s3-secret is source env");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptOnline), false, "    online is not set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptOnline), cfgSourceParam, "    online is source default");
-        TEST_RESULT_BOOL(cfgOptionBool(cfgOptCompress), true, "    compress is set");
-        TEST_RESULT_INT(cfgOptionSource(cfgOptCompress), cfgSourceDefault, "    compress is source default");
         TEST_RESULT_INT(cfgOptionInt(cfgOptBufferSize), 4194304, "    buffer-size is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptBufferSize), cfgSourceDefault, "    buffer-size is source default");
 
@@ -1193,7 +1189,7 @@ testRun(void)
 
         setenv("PGBACKRESTXXX_NOTHING", "xxx", true);
         setenv("PGBACKREST_BOGUS", "xxx", true);
-        setenv("PGBACKREST_NO_COMPRESS", "xxx", true);
+        setenv("PGBACKREST_NO_DELTA", "xxx", true);
         setenv("PGBACKREST_RESET_REPO1_HOST", "", true);
         setenv("PGBACKREST_TARGET", "xxx", true);
         setenv("PGBACKREST_ONLINE", "y", true);
@@ -1212,8 +1208,8 @@ testRun(void)
                 "[global:backup]\n"
                 "repo1-hardlink=y\n"
                 "bogus=bogus\n"
-                "no-compress=y\n"
-                "reset-compress=y\n"
+                "no-delta=y\n"
+                "reset-delta=y\n"
                 "archive-copy=y\n"
                 "start-fast=y\n"
                 "online=y\n"
@@ -1222,7 +1218,7 @@ testRun(void)
                 "buffer-size=65536\n"
                 "\n"
                 "[db:backup]\n"
-                "compress=n\n"
+                "delta=n\n"
                 "recovery-option=a=b\n"
                 "\n"
                 "[db]\n"
@@ -1235,28 +1231,28 @@ testRun(void)
             strPtr(
                 strNew(
                     "P00   WARN: environment contains invalid option 'bogus'\n"
-                    "P00   WARN: environment contains invalid negate option 'no-compress'\n"
+                    "P00   WARN: environment contains invalid negate option 'no-delta'\n"
                     "P00   WARN: environment contains invalid reset option 'reset-repo1-host'\n"
                     "P00   WARN: configuration file contains option 'recovery-option' invalid for section 'db:backup'\n"
                     "P00   WARN: configuration file contains invalid option 'bogus'\n"
-                    "P00   WARN: configuration file contains negate option 'no-compress'\n"
-                    "P00   WARN: configuration file contains reset option 'reset-compress'\n"
+                    "P00   WARN: configuration file contains negate option 'no-delta'\n"
+                    "P00   WARN: configuration file contains reset option 'reset-delta'\n"
                     "P00   WARN: configuration file contains command-line only option 'online'\n"
                     "P00   WARN: configuration file contains stanza-only option 'pg1-path' in global section 'global:backup'")));
 
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptPgHost), false, "    pg1-host is not set (command line reset override)");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgPath)), "/path/to/db", "    pg1-path is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptPgPath), "/path/to/db", "    pg1-path is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptPgPath), cfgSourceConfig, "    pg1-path is source config");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptLockPath)), "/", "    lock-path is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptLockPath), "/", "    lock-path is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptLockPath), cfgSourceConfig, "    lock-path is source config");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptPgSocketPath)), "/path/to/socket", "    pg1-socket-path is set");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptPgSocketPath), "/path/to/socket", "    pg1-socket-path is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptPgSocketPath), cfgSourceConfig, "    pg1-socket-path is config param");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptOnline), false, "    online not is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptOnline), cfgSourceParam, "    online is source param");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptStartFast), false, "    start-fast not is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptStartFast), cfgSourceConfig, "    start-fast is config param");
-        TEST_RESULT_BOOL(cfgOptionBool(cfgOptCompress), false, "    compress not is set");
-        TEST_RESULT_INT(cfgOptionSource(cfgOptCompress), cfgSourceConfig, "    compress is source config");
+        TEST_RESULT_BOOL(cfgOptionBool(cfgOptDelta), true, "    delta not set");
+        TEST_RESULT_INT(cfgOptionSource(cfgOptDelta), cfgSourceConfig, "    delta is source config");
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptArchiveCheck), false, "    archive-check is not set");
         TEST_RESULT_BOOL(cfgOptionTest(cfgOptArchiveCopy), false, "    archive-copy is not set");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptRepoHardlink), true, "    repo-hardlink is set");
@@ -1267,11 +1263,11 @@ testRun(void)
         TEST_RESULT_INT(cfgOptionSource(cfgOptBackupStandby), cfgSourceDefault, "    backup-standby is source default");
         TEST_RESULT_BOOL(cfgOptionBool(cfgOptDelta), true, "    delta is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptDelta), cfgSourceConfig, "    delta is source config");
-        TEST_RESULT_BOOL(cfgOptionInt64(cfgOptBufferSize), 65536, "    buffer-size is set");
+        TEST_RESULT_INT(cfgOptionInt64(cfgOptBufferSize), 65536, "    buffer-size is set");
         TEST_RESULT_INT(cfgOptionSource(cfgOptBufferSize), cfgSourceConfig, "    backup-standby is source config");
 
         unsetenv("PGBACKREST_BOGUS");
-        unsetenv("PGBACKREST_NO_COMPRESS");
+        unsetenv("PGBACKREST_NO_DELTA");
         unsetenv("PGBACKREST_RESET_REPO1_HOST");
         unsetenv("PGBACKREST_TARGET");
         unsetenv("PGBACKREST_ONLINE");
@@ -1336,8 +1332,8 @@ testRun(void)
 
         const VariantList *includeList = NULL;
         TEST_ASSIGN(includeList, cfgOptionLst(cfgOptDbInclude), "get db include options");
-        TEST_RESULT_STR(strPtr(varStr(varLstGet(includeList, 0))), "abc", "check db include option");
-        TEST_RESULT_STR(strPtr(varStr(varLstGet(includeList, 1))), "def", "check db include option");
+        TEST_RESULT_STR_Z(varStr(varLstGet(includeList, 0)), "abc", "check db include option");
+        TEST_RESULT_STR_Z(varStr(varLstGet(includeList, 1)), "def", "check db include option");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -1351,8 +1347,8 @@ testRun(void)
 
         const KeyValue *recoveryKv = NULL;
         TEST_ASSIGN(recoveryKv, cfgOptionKv(cfgOptRecoveryOption), "get recovery options");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("a"))))), "b", "check recovery option");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("c"))))), "de=fg hi", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("a")))), "b", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("c")))), "de=fg hi", "check recovery option");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -1374,8 +1370,8 @@ testRun(void)
         TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), TEST_COMMAND_RESTORE " command");
 
         TEST_ASSIGN(recoveryKv, cfgOptionKv(cfgOptRecoveryOption), "get recovery options");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("f"))))), "g", "check recovery option");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("hijk"))))), "l", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("f")))), "g", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("hijk")))), "l", "check recovery option");
 
         // -------------------------------------------------------------------------------------------------------------------------
         argList = strLstNew();
@@ -1390,9 +1386,9 @@ testRun(void)
         TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), TEST_COMMAND_RESTORE " command");
 
         TEST_ASSIGN(recoveryKv, cfgOptionKv(cfgOptRecoveryOption), "get recovery options");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("f"))))), "g", "check recovery option");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(recoveryKv, varNewStr(strNew("hijk"))))), "l", "check recovery option");
-        TEST_RESULT_STR(strPtr(varStr(varLstGet(cfgOptionLst(cfgOptDbInclude), 0))), "77", "check db include option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("f")))), "g", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(kvGet(recoveryKv, varNewStr(strNew("hijk")))), "l", "check recovery option");
+        TEST_RESULT_STR_Z(varStr(varLstGet(cfgOptionLst(cfgOptDbInclude), 0)), "77", "check db include option");
         TEST_RESULT_UINT(varLstSize(cfgOptionLst(cfgOptDbInclude)), 1, "check db include option size");
 
         unsetenv("PGBACKREST_STANZA");
@@ -1417,7 +1413,7 @@ testRun(void)
                 "repo1-path=/not/the/path\n"));
 
         TEST_RESULT_VOID(configParse(strLstSize(argList), strLstPtr(argList), false), "info command");
-        TEST_RESULT_STR(strPtr(cfgOptionStr(cfgOptRepoPath)), "/path/to/repo", "check repo1-path option");
+        TEST_RESULT_STR_Z(cfgOptionStr(cfgOptRepoPath), "/path/to/repo", "check repo1-path option");
     }
 
     // *****************************************************************************************************************************
