@@ -57,7 +57,7 @@ testRun(void)
             infoBackup, infoBackupNew(PG_VERSION_94, 6569239123849665679, NULL),
             "infoBackupNew() - no cipher sub");
         TEST_RESULT_VOID(infoBackupSave(infoBackup, ioBufferWriteNew(contentCompare)), "    save backup info from new");
-        TEST_RESULT_STR(strPtr(strNewBuf(contentCompare)), strPtr(strNewBuf(contentSave)), "   check save");
+        TEST_RESULT_STR(strNewBuf(contentCompare), strNewBuf(contentSave), "   check save");
 
         TEST_ASSIGN(infoBackup, infoBackupNewLoad(ioBufferReadNew(contentCompare)), "load backup info");
         TEST_RESULT_PTR(infoBackupPg(infoBackup), infoBackup->infoPg, "    infoPg set");
@@ -79,7 +79,7 @@ testRun(void)
         infoBackup = NULL;
         TEST_ASSIGN(infoBackup, infoBackupNewLoad(ioBufferReadNew(contentSave)), "    load backup info with cipher sub");
         TEST_RESULT_PTR(infoBackupPg(infoBackup), infoBackup->infoPg, "    infoPg set");
-        TEST_RESULT_STR(strPtr(infoBackupCipherPass(infoBackup)),
+        TEST_RESULT_STR_Z(infoBackupCipherPass(infoBackup),
             "zWa/6Xtp-IVZC5444yXB+cgFDFl7MxGlgkZSaoPvTGirhPygu4jOKOXf9LO4vjfO", "    cipher sub set");
         TEST_RESULT_INT(infoPgDataTotal(infoBackup->infoPg), 1, "    history set");
 
@@ -90,7 +90,7 @@ testRun(void)
         TEST_RESULT_INT(infoPgDataTotal(infoBackup->infoPg), 2, "    history incremented");
         TEST_ASSIGN(infoPgData, infoPgDataCurrent(infoBackup->infoPg), "    get current infoPgData");
         TEST_RESULT_INT(infoPgData.version, PG_VERSION_94, "    version set");
-        TEST_RESULT_INT(infoPgData.systemId, 6569239123849665679, "    systemId set");
+        TEST_RESULT_UINT(infoPgData.systemId, 6569239123849665679, "    systemId set");
 
         // Free
         //--------------------------------------------------------------------------------------------------------------------------
@@ -140,40 +140,41 @@ testRun(void)
 
         InfoBackupData backupData = infoBackupData(infoBackup, 0);
 
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20161219-212741F", "full backup label");
-        TEST_RESULT_STR(strPtr(backupData.backupType), "full", "    backup type full");
+        TEST_RESULT_STR_Z(backupData.backupLabel, "20161219-212741F", "full backup label");
+        TEST_RESULT_STR_Z(backupData.backupType, "full", "    backup type full");
         TEST_RESULT_INT(backupData.backrestFormat, 5, "    backrest format");
-        TEST_RESULT_STR(strPtr(backupData.backrestVersion), "2.04", "    backrest version");
-        TEST_RESULT_STR(strPtr(backupData.backupArchiveStart), "00000007000000000000001C", "    archive start");
-        TEST_RESULT_STR(strPtr(backupData.backupArchiveStop), "00000007000000000000001C", "    archive stop");
-        TEST_RESULT_INT(backupData.backupInfoRepoSize, 3159776, "    repo size");
-        TEST_RESULT_INT(backupData.backupInfoRepoSizeDelta, 3159776, "    repo delta");
-        TEST_RESULT_INT(backupData.backupInfoSize, 26897030, "    backup size");
-        TEST_RESULT_INT(backupData.backupInfoSizeDelta, 26897030, "    backup delta");
+        TEST_RESULT_STR_Z(backupData.backrestVersion, "2.04", "    backrest version");
+        TEST_RESULT_STR_Z(backupData.backupArchiveStart, "00000007000000000000001C", "    archive start");
+        TEST_RESULT_STR_Z(backupData.backupArchiveStop, "00000007000000000000001C", "    archive stop");
+        TEST_RESULT_UINT(backupData.backupInfoRepoSize, 3159776, "    repo size");
+        TEST_RESULT_UINT(backupData.backupInfoRepoSizeDelta, 3159776, "    repo delta");
+        TEST_RESULT_UINT(backupData.backupInfoSize, 26897030, "    backup size");
+        TEST_RESULT_UINT(backupData.backupInfoSizeDelta, 26897030, "    backup delta");
         TEST_RESULT_INT(backupData.backupPgId, 1, "    pg id");
         TEST_RESULT_PTR(backupData.backupPrior, NULL, "    backup prior NULL");
         TEST_RESULT_PTR(backupData.backupReference, NULL, "    backup reference NULL");
         TEST_RESULT_INT(backupData.backupTimestampStart, 1482182846, "    timestamp start");
         TEST_RESULT_INT(backupData.backupTimestampStop, 1482182861, "    timestamp stop");
 
-        backupData = infoBackupData(infoBackup, 1);
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20161219-212741F_20161219-212803D", "diff backup label");
-        TEST_RESULT_STR(strPtr(backupData.backupType), "diff", "    backup type diff");
-        TEST_RESULT_INT(backupData.backupInfoRepoSize, 3159811, "    repo size");
-        TEST_RESULT_INT(backupData.backupInfoRepoSizeDelta, 15765, "    repo delta");
-        TEST_RESULT_INT(backupData.backupInfoSize, 26897030, "    backup size");
-        TEST_RESULT_INT(backupData.backupInfoSizeDelta, 163866, "    backup delta");
-        TEST_RESULT_STR(strPtr(backupData.backupPrior), "20161219-212741F", "    backup prior exists");
+        InfoBackupData *backupDataPtr = infoBackupDataByLabel(infoBackup, STRDEF("20161219-212741F_20161219-212803D"));
+        TEST_RESULT_STR_Z(backupDataPtr->backupLabel, "20161219-212741F_20161219-212803D", "diff backup label");
+        TEST_RESULT_STR_Z(backupDataPtr->backupType, "diff", "    backup type diff");
+        TEST_RESULT_UINT(backupDataPtr->backupInfoRepoSize, 3159811, "    repo size");
+        TEST_RESULT_UINT(backupDataPtr->backupInfoRepoSizeDelta, 15765, "    repo delta");
+        TEST_RESULT_UINT(backupDataPtr->backupInfoSize, 26897030, "    backup size");
+        TEST_RESULT_UINT(backupDataPtr->backupInfoSizeDelta, 163866, "    backup delta");
+        TEST_RESULT_STR_Z(backupDataPtr->backupPrior, "20161219-212741F", "    backup prior exists");
         TEST_RESULT_BOOL(
-            (strLstSize(backupData.backupReference) == 1 && strLstExistsZ(backupData.backupReference, "20161219-212741F")), true,
+            (strLstSize(backupDataPtr->backupReference) == 1 && strLstExistsZ(backupDataPtr->backupReference, "20161219-212741F")), true,
             "    backup reference exists");
+        TEST_RESULT_PTR(infoBackupDataByLabel(infoBackup, STRDEF("20161219-12345")), NULL, "    backup label does not exist");
 
         backupData = infoBackupData(infoBackup, 2);
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20161219-212741F_20161219-212918I", "incr backup label");
+        TEST_RESULT_STR_Z(backupData.backupLabel, "20161219-212741F_20161219-212918I", "incr backup label");
         TEST_RESULT_PTR(backupData.backupArchiveStart, NULL, "    archive start NULL");
         TEST_RESULT_PTR(backupData.backupArchiveStop, NULL, "    archive stop NULL");
-        TEST_RESULT_STR(strPtr(backupData.backupType), "incr", "    backup type incr");
-        TEST_RESULT_STR(strPtr(backupData.backupPrior), "20161219-212741F", "    backup prior exists");
+        TEST_RESULT_STR_Z(backupData.backupType, "incr", "    backup type incr");
+        TEST_RESULT_STR_Z(backupData.backupPrior, "20161219-212741F", "    backup prior exists");
         TEST_RESULT_BOOL(
             (strLstSize(backupData.backupReference) == 2 && strLstExistsZ(backupData.backupReference, "20161219-212741F") &&
             strLstExistsZ(backupData.backupReference, "20161219-212741F_20161219-212803D")), true, "    backup reference exists");
@@ -189,32 +190,33 @@ testRun(void)
         contentSave = bufNew(0);
 
         TEST_RESULT_VOID(infoBackupSave(infoBackup, ioBufferWriteNew(contentSave)), "info backup save");
-        TEST_RESULT_STR(strPtr(strNewBuf(contentSave)), strPtr(strNewBuf(contentLoad)), "   check save");
+        TEST_RESULT_STR(strNewBuf(contentSave), strNewBuf(contentLoad), "   check save");
 
         // infoBackupDataLabelList and infoBackupDataDelete
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", "),
             "20161219-212741F, 20161219-212741F_20161219-212803D, 20161219-212741F_20161219-212918I",
             "infoBackupDataLabelList without expression");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(infoBackupDataLabelList(
-                infoBackup, backupRegExpP(.full=true, .differential=true, .incremental=true)), sortOrderAsc), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(
+                strLstSort(
+                    infoBackupDataLabelList(
+                        infoBackup, backupRegExpP(.full = true, .differential = true, .incremental = true)), sortOrderAsc), ", "),
             "20161219-212741F, 20161219-212741F_20161219-212803D, 20161219-212741F_20161219-212918I",
             "infoBackupDataLabelList with expression");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.full=true)), ", ")),
-            "20161219-212741F", "  full=true");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.differential=true)), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.full=true)), ", "), "20161219-212741F", "  full=true");
+        TEST_RESULT_STR_Z(
+            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.differential=true)), ", "),
             "20161219-212741F_20161219-212803D", "differential=true");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.incremental=true)), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(infoBackupDataLabelList(infoBackup, backupRegExpP(.incremental=true)), ", "),
             "20161219-212741F_20161219-212918I", "incremental=true");
 
         TEST_RESULT_VOID(infoBackupDataDelete(infoBackup, strNew("20161219-212741F_20161219-212918I")), "delete a backup");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderAsc), ", "),
             "20161219-212741F, 20161219-212741F_20161219-212803D", "  backup deleted");
 
         TEST_RESULT_VOID(infoBackupDataDelete(infoBackup, strNew("20161219-212741F_20161219-212803D")), "delete all backups");
@@ -223,8 +225,8 @@ testRun(void)
 
         // infoBackupDataToLog
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(
-            strPtr(infoBackupDataToLog(&backupData)), "{label: 20161219-212741F_20161219-212918I, pgId: 1}", "check log format");
+        TEST_RESULT_STR_Z(
+            infoBackupDataToLog(&backupData), "{label: 20161219-212741F_20161219-212918I, pgId: 1}", "check log format");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("infoBackupDataAdd - full backup");
@@ -299,13 +301,13 @@ testRun(void)
         TEST_RESULT_VOID(infoBackupDataAdd(infoBackup, manifest), "add a backup");
         TEST_RESULT_UINT(infoBackupDataTotal(infoBackup), 1, "backup added to current");
         TEST_ASSIGN(backupData, infoBackupData(infoBackup, 0), "get added backup");
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20190818-084502F", "backup label set");
+        TEST_RESULT_STR_Z(backupData.backupLabel, "20190818-084502F", "backup label set");
         TEST_RESULT_UINT(backupData.backrestFormat, REPOSITORY_FORMAT, "backrest format");
-        TEST_RESULT_STR(strPtr(backupData.backrestVersion), PROJECT_VERSION, "backuprest version");
+        TEST_RESULT_STR_Z(backupData.backrestVersion, PROJECT_VERSION, "backuprest version");
         TEST_RESULT_INT(backupData.backupPgId, 1, "pg id");
         TEST_RESULT_PTR(backupData.backupArchiveStart, NULL, "archive start NULL");
         TEST_RESULT_PTR(backupData.backupArchiveStop, NULL, "archive stop NULL");
-        TEST_RESULT_STR(strPtr(backupData.backupType), "full", "backup type set");
+        TEST_RESULT_STR_Z(backupData.backupType, "full", "backup type set");
         TEST_RESULT_PTR(strPtr(backupData.backupPrior), NULL, "no backup prior");
         TEST_RESULT_PTR(backupData.backupReference, NULL, "no backup reference");
         TEST_RESULT_INT(backupData.backupTimestampStart, 1565282140, "timestamp start");
@@ -407,15 +409,15 @@ testRun(void)
         TEST_RESULT_VOID(infoBackupDataAdd(infoBackup, manifest), "add a backup");
         TEST_RESULT_UINT(infoBackupDataTotal(infoBackup), 2, "backup added to current");
         TEST_ASSIGN(backupData, infoBackupData(infoBackup, 1), "get added backup");
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20190818-084502F_20190820-084502I", "backup label set");
+        TEST_RESULT_STR_Z(backupData.backupLabel, "20190818-084502F_20190820-084502I", "backup label set");
         TEST_RESULT_UINT(backupData.backrestFormat, REPOSITORY_FORMAT, "backrest format");
-        TEST_RESULT_STR(strPtr(backupData.backrestVersion), PROJECT_VERSION, "backuprest version");
-        TEST_RESULT_STR(strPtr(backupData.backupArchiveStart), "000000030000028500000089", "archive start set");
-        TEST_RESULT_STR(strPtr(backupData.backupArchiveStop), "000000030000028500000090", "archive stop set");
-        TEST_RESULT_STR(strPtr(backupData.backupType), "diff", "backup type set");
-        TEST_RESULT_STR(strPtr(backupData.backupPrior), "20190818-084502F", "backup prior set");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(backupData.backupReference, ", ")),
+        TEST_RESULT_STR_Z(backupData.backrestVersion, PROJECT_VERSION, "backuprest version");
+        TEST_RESULT_STR_Z(backupData.backupArchiveStart, "000000030000028500000089", "archive start set");
+        TEST_RESULT_STR_Z(backupData.backupArchiveStop, "000000030000028500000090", "archive stop set");
+        TEST_RESULT_STR_Z(backupData.backupType, "diff", "backup type set");
+        TEST_RESULT_STR_Z(backupData.backupPrior, "20190818-084502F", "backup prior set");
+        TEST_RESULT_STR_Z(
+            strLstJoin(backupData.backupReference, ", "),
             "20190818-084502F, 20190818-084502F_20190819-084506D, 20190818-084502F_20190819-084506I",
             "backup reference set and ordered");
         TEST_RESULT_BOOL(backupData.optionArchiveCheck, true, "option archive check");
@@ -670,9 +672,14 @@ testRun(void)
             storagePathCreateP(storageRepoWrite(), strNew(STORAGE_REPO_BACKUP "/20190818-084502F")),
             "create backup on disk that is in current but no manifest");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageRepo(), STORAGE_REPO_BACKUP_STR,
-            .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)), sortOrderAsc), ", ")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(
+                strLstSort(
+                    storageListP(
+                        storageRepo(), STORAGE_REPO_BACKUP_STR,
+                        .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
+                    sortOrderAsc),
+                ", "),
             "20190818-084444F, 20190818-084502F, 20190818-084555F, 20190818-084666F, 20190818-084777F, 20190923-164324F",
             "confirm backups on disk");
 
@@ -693,7 +700,8 @@ testRun(void)
             "reconstruct");
         TEST_RESULT_INT(infoBackupDataTotal(infoBackup), 1, "backup list contains 1 backup");
         TEST_ASSIGN(backupData, infoBackupData(infoBackup, 0), "get the backup");
-        TEST_RESULT_STR(strPtr(backupData.backupLabel), "20190923-164324F",
+        TEST_RESULT_STR_Z(
+            backupData.backupLabel, "20190923-164324F",
             "backups not on disk removed, valid backup on disk added, manifest copy-only ignored");
         harnessLogResult(
             "P00   WARN: invalid backup '20190818-084555F' cannot be added to current backups\n"
@@ -716,8 +724,8 @@ testRun(void)
         TEST_ASSIGN(
             infoBackup, infoBackupLoadFileReconstruct(storageRepo(), INFO_BACKUP_PATH_FILE_STR, cipherTypeNone, NULL),
             "reconstruct");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(infoBackupDataLabelList(infoBackup, NULL), ", ")), "20190818-084444F, 20190923-164324F",
+        TEST_RESULT_STR_Z(
+            strLstJoin(infoBackupDataLabelList(infoBackup, NULL), ", "), "20190818-084444F, 20190923-164324F",
             "previously ignored pgId=1 manifest copy-only now added before existing");
         harnessLogResult(
             "P00   WARN: backup '20190818-084444F' found in repository added to backup.info\n"
@@ -749,4 +757,112 @@ testRun(void)
         TEST_ASSIGN(infoBackup, infoBackupLoadFile(storageTest, STRDEF(INFO_BACKUP_FILE), cipherTypeNone, NULL), "load copy");
         TEST_RESULT_UINT(infoPgDataCurrent(infoBackup->infoPg).systemId, 6569239123849665999, "    check file loaded");
     }
+
+    // *****************************************************************************************************************************
+    if (testBegin("infoBackupDataDependentList()"))
+    {
+        const Buffer *contentLoad = harnessInfoChecksumZ(
+            "[backup:current]\n"
+            "20200317-181416F={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"000000080000000000000020\",\"backup-archive-stop\":\"000000080000000000000020\","
+            "\"backup-info-repo-size\":3687611,\"backup-info-repo-size-delta\":3687611,\"backup-info-size\":31230816,"
+            "\"backup-info-size-delta\":31230816,\"backup-timestamp-start\":1584468856,\"backup-timestamp-stop\":1584468864,"
+            "\"backup-type\":\"full\",\"db-id\":1,\"option-archive-check\":true,\"option-archive-copy\":false,"
+            "\"option-backup-standby\":false,\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,"
+            "\"option-online\":true}\n"
+            "20200317-181625F={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"000000010000000000000038\",\"backup-archive-stop\":\"000000010000000000000038\","
+            "\"backup-info-repo-size\":3768898,\"backup-info-repo-size-delta\":3768898,\"backup-info-size\":31533937,"
+            "\"backup-info-size-delta\":31533937,\"backup-timestamp-start\":1584468985,\"backup-timestamp-stop\":1584468992,"
+            "\"backup-type\":\"full\",\"db-id\":2,\"option-archive-check\":true,\"option-archive-copy\":false,"
+            "\"option-backup-standby\":false,\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,"
+            "\"option-online\":true}\n"
+            "20200317-181625F_20200317-182239D={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"00000001000000000000003A\",\"backup-archive-stop\":\"00000001000000000000003A\","
+            "\"backup-info-repo-size\":3768734,\"backup-info-repo-size-delta\":138783,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":1204491,\"backup-prior\":\"20200317-181625F\",\"backup-reference\":[\"20200317-181625F\"],"
+            "\"backup-timestamp-start\":1584469359,\"backup-timestamp-stop\":1584469362,\"backup-type\":\"diff\",\"db-id\":2,"
+            "\"option-archive-check\":true,\"option-archive-copy\":false,\"option-backup-standby\":true,"
+            "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
+            "20200317-181625F_20200317-182300D={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"00000001000000000000003C\",\"backup-archive-stop\":\"00000001000000000000003C\","
+            "\"backup-info-repo-size\":3768733,\"backup-info-repo-size-delta\":138782,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":1204491,\"backup-prior\":\"20200317-181625F\",\"backup-reference\":[\"20200317-181625F\"],"
+            "\"backup-timestamp-start\":1584469380,\"backup-timestamp-stop\":1584469383,\"backup-type\":\"diff\",\"db-id\":2,"
+            "\"option-archive-check\":true,\"option-archive-copy\":false,\"option-backup-standby\":true,"
+            "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
+            "20200317-181625F_20200317-182324I={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"00000001000000000000003E\",\"backup-archive-stop\":\"00000001000000000000003E\","
+            "\"backup-info-repo-size\":3768731,\"backup-info-repo-size-delta\":431,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":8459,\"backup-prior\":\"20200317-181625F_20200317-182300D\","
+            "\"backup-reference\":[\"20200317-181625F\",\"20200317-181625F_20200317-182300D\"],"
+            "\"backup-timestamp-start\":1584469404,\"backup-timestamp-stop\":1584469406,\"backup-type\":\"incr\",\"db-id\":2,"
+            "\"option-archive-check\":true,\"option-archive-copy\":false,\"option-backup-standby\":true,"
+            "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
+            "20200317-181625F_20200317-182340I={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"000000010000000000000040\",\"backup-archive-stop\":\"000000010000000000000040\","
+            "\"backup-info-repo-size\":3768733,\"backup-info-repo-size-delta\":433,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":8459,\"backup-prior\":\"20200317-181625F_20200317-182324I\","
+            "\"backup-reference\":[\"20200317-181625F\",\"20200317-181625F_20200317-182300D\"],"
+            "\"backup-timestamp-start\":1584469420,\"backup-timestamp-stop\":1584469423,\"backup-type\":\"incr\",\"db-id\":2,"
+            "\"option-archive-check\":true,\"option-archive-copy\":false,\"option-backup-standby\":true,"
+            "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
+            "20200317-181625F_20200317-182340D={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"000000010000000000000041\",\"backup-archive-stop\":\"000000010000000000000041\","
+            "\"backup-info-repo-size\":3768733,\"backup-info-repo-size-delta\":433,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":8459,\"backup-prior\":\"20200317-181625F\",\"backup-reference\":[\"20200317-181625F\"],"
+            "\"backup-timestamp-start\":1584469420,\"backup-timestamp-stop\":1584469423,\"backup-type\":\"incr\",\"db-id\":2,"
+            "\"option-archive-check\":true,\"option-archive-copy\":false,\"option-backup-standby\":true,"
+            "\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,\"option-online\":true}\n"
+            "20200318-153815F={\"backrest-format\":5,\"backrest-version\":\"2.25dev\","
+            "\"backup-archive-start\":\"000000010000000000000042\",\"backup-archive-stop\":\"000000010000000000000042\","
+            "\"backup-info-repo-size\":3768732,\"backup-info-repo-size-delta\":3768732,\"backup-info-size\":31558514,"
+            "\"backup-info-size-delta\":31558514,\"backup-timestamp-start\":1584545895,\"backup-timestamp-stop\":1584545905,"
+            "\"backup-type\":\"full\",\"db-id\":2,\"option-archive-check\":true,\"option-archive-copy\":false,"
+            "\"option-backup-standby\":true,\"option-checksum-page\":true,\"option-compress\":true,\"option-hardlink\":false,"
+            "\"option-online\":true}\n"
+            "\n"
+            "[db]\n"
+            "db-catalog-version=201409291\n"
+            "db-control-version=942\n"
+            "db-id=1\n"
+            "db-system-id=6569239123849665679\n"
+            "db-version=\"9.4\"\n"
+            "\n"
+            "[db:history]\n"
+            "1={\"db-catalog-version\":201409291,\"db-control-version\":942,\"db-system-id\":6569239123849665679,"
+                "\"db-version\":\"9.4\"}\n");
+
+        InfoBackup *infoBackup;
+        StringList *dependencyList;
+
+        TEST_TITLE("check dependency lists");
+
+        TEST_ASSIGN(infoBackup, infoBackupNewLoad(ioBufferReadNew(contentLoad)), "new backup info");
+
+        TEST_ASSIGN(
+            dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F")), "full");
+        TEST_RESULT_STR_Z(
+            strLstJoin(dependencyList, ", "),
+            "20200317-181625F, 20200317-181625F_20200317-182239D, 20200317-181625F_20200317-182300D, "
+            "20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I, 20200317-181625F_20200317-182340D",
+            "all dependents");
+
+        TEST_ASSIGN(
+            dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181416F")), "full");
+        TEST_RESULT_STR_Z(strLstJoin(dependencyList, ", "), "20200317-181416F", "no dependents");
+
+        TEST_ASSIGN(
+            dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F_20200317-182300D")), "diff");
+        TEST_RESULT_STR_Z(
+            strLstJoin(dependencyList, ", "),
+            "20200317-181625F_20200317-182300D, 20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I",
+            "all dependents");
+
+        TEST_ASSIGN(
+            dependencyList, infoBackupDataDependentList(infoBackup, STRDEF("20200317-181625F_20200317-182324I")), "incr");
+        TEST_RESULT_STR_Z(
+            strLstJoin(dependencyList, ", "), "20200317-181625F_20200317-182324I, 20200317-181625F_20200317-182340I",
+            "all dependents");
+    }
 }
